@@ -19,7 +19,6 @@
 #include <qlayout.h>
 #include <qlineedit.h>
 #include <qcheckbox.h>
-#include <qpushbutton.h>
 #include <qbuttongroup.h>
 #include <qpainter.h>
 #include <qpalette.h>
@@ -29,6 +28,8 @@
 #include <klocale.h>
 #include <kfiledialog.h>
 #include <kmessagebox.h>
+#include <kpushbutton.h>
+#include <kstdguiitem.h>
 
 #include "cttask.h"
 
@@ -37,7 +38,7 @@
 class KTPushButton : public QPushButton
 {
 public:
-   KTPushButton(QWidget * parent, const char * name = 0 ) 
+   KTPushButton(QWidget * parent, const char * name = 0 )
      : QPushButton(parent, name), isSelected(false), isDirty(false)
    {
       updatePalette();
@@ -49,9 +50,9 @@ public:
       palSelected = palNormal;
       for(int cg = (int) QPalette::Disabled; cg < (int) QPalette::NColorGroups; cg++)
       {
-        palSelected.setColor((QPalette::ColorGroup)cg, QColorGroup::Button, 
+        palSelected.setColor((QPalette::ColorGroup)cg, QColorGroup::Button,
                      palSelected.color((QPalette::ColorGroup)cg, QColorGroup::Highlight));
-        palSelected.setColor((QPalette::ColorGroup)cg, QColorGroup::ButtonText, 
+        palSelected.setColor((QPalette::ColorGroup)cg, QColorGroup::ButtonText,
                      palSelected.color((QPalette::ColorGroup)cg, QColorGroup::HighlightedText));
       }
       isDirty = true;
@@ -66,7 +67,7 @@ public:
      }
      return QPushButton::event(e);
    }
-   
+
    void drawButton ( QPainter *p )
    {
      if (isDirty || (isOn() != isSelected)) // Prevent infinite recursion
@@ -326,12 +327,12 @@ KTTask::KTTask(CTTask* _cttask, const QString & _caption)
   h5->addStretch( 1 );
 
   // OK
-  pbOk = new QPushButton(i18n("&OK"), this, "pbOk");
+  pbOk = new KPushButton(KStdGuiItem::ok(), this, "pbOk");
   pbOk->setDefault(true);
   h5->addWidget( pbOk );
 
   // Cancel
-  pbCancel = new QPushButton(i18n("&Cancel"), this, "pbCancel");
+  pbCancel = new KPushButton(KStdGuiItem::cancel(), this, "pbCancel");
   h5->addWidget( pbCancel );
 
   // window
@@ -358,9 +359,9 @@ KTTask::KTTask(CTTask* _cttask, const QString & _caption)
 
   // key acceleration
   key_accel = new KAccel(this);
-  key_accel->connectItem(KStdAccel::Open, this, SLOT(slotOK()));
-  key_accel->connectItem(KStdAccel::Close, this, SLOT(slotCancel()));
-  key_accel->connectItem(KStdAccel::Quit, this, SLOT(slotCancel()));
+  key_accel->insert(KStdAccel::Open, this, SLOT(slotOK()));
+  key_accel->insert(KStdAccel::Close, this, SLOT(slotCancel()));
+  key_accel->insert(KStdAccel::Quit, this, SLOT(slotCancel()));
   key_accel->readSettings();
 
   setFixedSize( minimumSize() );
