@@ -103,7 +103,7 @@ void KTVariable::slotVariableChanged()
   if (variable == "HOME")
   {
     labIcon->setPixmap(KTIcon::home(false));
-    mleComment->setText(i18n("Override default home directory."));
+    mleComment->setText(i18n("Override default home folder."));
   }
   else if (variable == "MAILTO")
   {
@@ -118,7 +118,7 @@ void KTVariable::slotVariableChanged()
   else if (variable == "PATH")
   {
     labIcon->setPixmap(KTIcon::path(false));
-    mleComment->setText(i18n("Directories to search for program files."));
+    mleComment->setText(i18n("Folders to search for program files."));
   }
   else
   {
@@ -161,7 +161,7 @@ void KTVariable::autoWrap()
   while(pos < s.length())
   {
     int foundat = s.findRev(" ", pos);
-    if (foundat > 0)
+    if (foundat)
       s.replace(foundat, 1, "\n");
     pos = foundat+maxCharWidth;
   }
