@@ -1,5 +1,6 @@
 // KDat - a tar-based DAT archiver
-// Copyright (C) 1998  Sean Vyain, svyain@mail.tds.net
+// Copyright (C) 1998-2000  Sean Vyain, svyain@mail.tds.net
+// Copyright (C) 2001-2002  Lawrence Widman, kdat@cardiothink.com
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
@@ -20,7 +21,7 @@
 
 #include <stdio.h>
 
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qstring.h>
 
 #include "File.h"
@@ -38,7 +39,7 @@ class Archive {
     FILE*       _fptr;
     int         _offset;
     QString     _name;
-    QList<File> _children;
+    QPtrList<File> _children;
     RangeList   _ranges;
     Tape*       _tape;
 public:
@@ -80,7 +81,7 @@ public:
     void read( int version = KDAT_INDEX_FILE_VERSION );
 
     /**
-     * Recursively read the instance data for this archive entry and all of it's
+     * Recursively read the instance data for this archive entry and all of its
      * children.  This method is used when converting from an older index format.
      *
      * @param version The version of the old tape index.
@@ -126,14 +127,14 @@ public:
      *
      * @return A list of the immediate children of this archive.
      */
-    const QList<File>& getChildren();
+    const QPtrList<File>& getChildren();
 
     /**
      * Get the list of ranges of this file and all of its children.
      *
      * @return A list of ranges.
      */
-    const QList<Range>& getRanges();
+    const QPtrList<Range>& getRanges();
 
     /**
      * Set the ending tape block for this archive.
