@@ -1,4 +1,4 @@
-// $Id: BackupDlg.cpp,v 1.22 2002/08/11 09:00:12 binner Exp $
+// $Id: BackupDlg.cpp,v 1.22.4.1 2004/04/12 17:04:25 binner Exp $
 //
 // KDat - a tar-based DAT archiver
 // Copyright (C) 1998-2000  Sean Vyain, svyain@mail.tds.net
@@ -33,6 +33,8 @@
 #include <kapplication.h>
 #include <kprocess.h>
 #include <kmessagebox.h>
+#include <kpushbutton.h>
+#include <kstdguiitem.h>
 
 #include "Archive.h"
 #include "BackupDlg.h"
@@ -78,7 +80,7 @@ BackupDlg::BackupDlg( const QString & archiveName, const QString & workingDir, c
 
     resize( 515, 300 );
 
-    /* 2002-01-26 LEW: "Time remaining" was cut off in mid-"g" 
+    /* 2002-01-26 LEW: "Time remaining" was cut off in mid-"g"
        so we'll provide that plus some space beyond it. */
     // const int labelWidth = 96;
     const int labelWidth = 110;
@@ -127,7 +129,7 @@ BackupDlg::BackupDlg( const QString & archiveName, const QString & workingDir, c
 
     _log = new LoggerWidget( i18n( "Backup log:" ), this );
 
-    _ok = new QPushButton( i18n( "&OK" ), this );
+    _ok = new KPushButton( KStdGuiItem::ok(), this );
     _ok->setFixedSize( 80, _ok->sizeHint().height() );
     connect( _ok, SIGNAL( clicked() ), this, SLOT( slotOK() ) );
     _ok->setEnabled( FALSE );
@@ -137,7 +139,7 @@ BackupDlg::BackupDlg( const QString & archiveName, const QString & workingDir, c
     connect( _save, SIGNAL( clicked() ), _log, SLOT( save() ) );
     _save->setEnabled( FALSE );
 
-    _abort = new QPushButton( i18n( "&Abort" ), this );
+    _abort = new KPushButton( KStdGuiItem::cancel(), this );
     _abort->setFixedSize( 80, _abort->sizeHint().height() );
     connect( _abort, SIGNAL( clicked() ), this, SLOT( slotAbort() ) );
 
@@ -276,7 +278,7 @@ void BackupDlg::show()
         KMessageBox::information(this, i18n("No files to back up. Aborting."));
         slotAbort();
         return;
-    }          
+    }
 
     connect( _proc, SIGNAL( processExited( KProcess* ) ), this, SLOT( slotProcessExited( KProcess* ) ) );
     connect( _proc, SIGNAL( receivedStdout( KProcess*, char*, int ) ), this, SLOT( slotStdout( KProcess*, char*, int ) ) );
