@@ -22,9 +22,10 @@
 #include <qlabel.h>
 #include <qlayout.h>
 #include <qlineedit.h>
-#include <qpushbutton.h>
 
 #include <kapplication.h>
+#include <kpushbutton.h>
+#include <kstdguiitem.h>
 
 #include "BackupProfile.h"
 #include "BackupProfileInfoWidget.h"
@@ -56,7 +57,7 @@ BackupProfileInfoWidget::BackupProfileInfoWidget( QWidget* parent, const char* n
     QPushButton* setSelection = new QPushButton( i18n( "<< Files" ), this );
     setSelection->setFixedSize( 80, setSelection->sizeHint().height() );
 
-    _apply = new QPushButton( i18n( "Apply" ), this );
+    _apply = new KPushButton( KStdGuiItem::apply(), this );
     _apply->setFixedSize( 80, _apply->sizeHint().height() );
     _apply->setEnabled( FALSE );
 
@@ -189,7 +190,7 @@ void BackupProfileInfoWidget::slotApply()
     _backupProfile->setIncremental( _profile->isIncremental() );
     _backupProfile->setSnapshotFile( _profile->getSnapshotFile() );
     _backupProfile->setRemoveSnapshot( _profile->getRemoveSnapshot() );
-    
+
     _backupProfile->save();
 
     _apply->setEnabled( FALSE );
