@@ -23,11 +23,12 @@
 
 #include <qlabel.h>
 #include <qlayout.h>
-#include <qpushbutton.h>
 
 #include <kapplication.h>
 #include <klocale.h>
 #include <kmessagebox.h>
+#include <kpushbutton.h>
+#include <kstdguiitem.h>
 
 #include "LoggerWidget.h"
 #include "Options.h"
@@ -106,7 +107,7 @@ IndexDlg::IndexDlg( Tape* tape, QWidget* parent, const char* name )
 
     _log = new LoggerWidget( i18n( "Index log:" ), this );
 
-    _ok = new QPushButton( i18n( "OK" ), this );
+    _ok = new KPushButton( KStdGuiItem::ok(), this );
     _ok->setFixedSize( 80, _ok->sizeHint().height() );
     connect( _ok, SIGNAL( clicked() ), this, SLOT( slotOK() ) );
     _ok->setEnabled( FALSE );
