@@ -38,6 +38,8 @@
 #include <kconfig.h>
 #include <kmessagebox.h>
 #include <kstringhandler.h>
+#include <kpushbutton.h>
+#include <kstdguiitem.h>
 
 #include "ArchiveInfoWidget.h"
 #include "BackupDlg.h"
@@ -141,14 +143,14 @@ KDat::KDat()
     _fileMenu->insertItem( i18n( "Delete Backup Profile" ), this, SLOT( fileDeleteBackupProfile() ) );
     _fileMenu->insertItem( i18n( "Format Tape..." )       , this, SLOT( fileFormatTape() ) );
     _fileMenu->insertSeparator();
-    _fileMenu->insertItem( i18n( "&Quit" )                , this, SLOT( fileQuit() ), CTRL + Key_Q );
+    _fileMenu->insertItem( SmallIcon("exit"), i18n( "&Quit" )                , this, SLOT( fileQuit() ), CTRL + Key_Q );
 
     _editMenu = new QPopupMenu;
-    _editMenu->insertItem( i18n( "Preferences..." )       , this, SLOT( editPreferences() ) );
+    _editMenu->insertItem( SmallIcon("configure"), i18n( "Configure KDat..." )       , this, SLOT( editPreferences() ) );
 
     _menu = new KMenuBar( this );
     _menu->insertItem( i18n( "&File" ), _fileMenu );
-    _menu->insertItem( i18n( "&Edit" ), _editMenu );
+    _menu->insertItem( i18n( "&Settings" ), _editMenu );
     _menu->insertSeparator();
     QString about = i18n( "KDat Version %1\n\nKDat is a tar-based tape archiver.\n\nCopyright (c) 1998-2000 Sean Vyain\nCopyright (c) 2001-2002 Lawrence Widman\nkdat@cardiothink.com" ).arg( KDAT_VERSION );
     _menu->insertItem( i18n( "&Help" ), helpMenu( about ) );
@@ -1351,7 +1353,7 @@ void KDat::create_backup_dialog()
   //  _lbl->setGeometry( QRect( 30, 20, 350, 140 ) );  /* 2002-01-28 LEW */
   _lbl->setGeometry( QRect( 30, 20, 350, 200 ) );
 
-  _cancel = new QPushButton( i18n( "&Cancel" ), _backupdialog );
+  _cancel = new KPushButton( KStdGuiItem::cancel(), _backupdialog );
   _cancel->setFixedSize( 80, _cancel->sizeHint().height() );
   _cancel->setEnabled( TRUE );
   /* 2002-01-24 LEW: looks like we can't increase the button width
@@ -1360,7 +1362,7 @@ void KDat::create_backup_dialog()
   _cancel->setGeometry( QRect( 50, 230, 0, 0 ) );
   connect( _cancel, SIGNAL( clicked() ), this, SLOT( backupCancel() ) );
 
-  _continue = new QPushButton( i18n( "C&ontinue" ), _backupdialog );
+  _continue = new KPushButton( KStdGuiItem::cont(), _backupdialog );
   _continue->setFixedSize( 80, _continue->sizeHint().height() );
   _continue->setEnabled( TRUE );
   _continue->setDefault( TRUE );
