@@ -1,4 +1,4 @@
-// $Id: OptionsDlg.cpp,v 1.22 2002/08/11 09:00:12 binner Exp $
+// $Id: OptionsDlg.cpp,v 1.23.2.1 2004/04/12 17:04:25 binner Exp $
 //
 // KDat - a tar-based DAT archiver
 // Copyright (C) 1998-2000  Sean Vyain, svyain@mail.tds.net
@@ -26,11 +26,12 @@
 #include <qlabel.h>
 #include <qlayout.h>
 #include <qlineedit.h>
-#include <qpushbutton.h>
 
 #include <kapplication.h>
 #include <kfiledialog.h>
 #include <kmessagebox.h>
+#include <kpushbutton.h>
+#include <kstdguiitem.h>
 
 #include "Options.h"
 #include "OptionsDlg.h"
@@ -63,15 +64,18 @@ OptionsDlg::OptionsDlg( QWidget* parent, const char* name )
     _defaultTapeSize = new KIntNumInput( this );
     _defaultTapeSize->setMinimumWidth( 48 );
     v2->addWidget( _defaultTapeSize );
+    connect( _defaultTapeSize, SIGNAL( valueChanged(int) ), this, SLOT( slotChanged() ) );
 
     _tapeBlockSize = new KIntNumInput( this );
     _tapeBlockSize->setMinimumWidth( 48 );
     v2->addWidget( _tapeBlockSize );
+    connect( _tapeBlockSize, SIGNAL( valueChanged(int) ), this, SLOT( slotChanged() ) );
 
     _defaultTapeSizeUnits = new QComboBox( this );
     _defaultTapeSizeUnits->insertItem( "MB" );
     _defaultTapeSizeUnits->insertItem( "GB" );
     v3->addWidget( _defaultTapeSizeUnits );
+    connect( _defaultTapeSizeUnits, SIGNAL( activated(int) ), this, SLOT( slotChanged() ) );
 
     QLabel* lbl5 = new QLabel( i18n( "bytes" ), this );
     v3->addWidget( lbl5 );
@@ -92,9 +96,11 @@ OptionsDlg::OptionsDlg( QWidget* parent, const char* name )
 
     _tapeDevice = new QLineEdit( this );
     v5->addWidget( _tapeDevice );
+    connect( _tapeDevice, SIGNAL( textChanged ( const QString & ) ), this, SLOT( slotChanged() ) );
 
     _tarCommand = new QLineEdit( this );
     v5->addWidget( _tarCommand );
+    connect( _tarCommand, SIGNAL( textChanged ( const QString & ) ), this, SLOT( slotChanged() ) );
 
     QPushButton* browseTapeDevice = new QPushButton( i18n( "..." ), this );
     v6->addWidget( browseTapeDevice );
@@ -112,28 +118,32 @@ OptionsDlg::OptionsDlg( QWidget* parent, const char* name )
 
     _loadOnMount = new QCheckBox( i18n( "Load tape on mount" ), g1 );
     v7->addWidget( _loadOnMount );
+    connect( _loadOnMount, SIGNAL( toggled(bool) ), this, SLOT( slotChanged() ) );
 
     _lockOnMount = new QCheckBox( i18n( "Lock tape drive on mount" ), g1 );
     v7->addWidget( _lockOnMount );
+    connect( _lockOnMount, SIGNAL( toggled(bool) ), this, SLOT( slotChanged() ) );
 
     _ejectOnUnmount = new QCheckBox( i18n( "Eject tape on unmount" ), g1 );
     v7->addWidget( _ejectOnUnmount );
+    connect( _ejectOnUnmount, SIGNAL( toggled(bool) ), this, SLOT( slotChanged() ) );
 
     _variableBlockSize = new QCheckBox( i18n( "Variable block size" ), g1 );
     v7->addWidget( _variableBlockSize );
+    connect( _variableBlockSize, SIGNAL( toggled(bool) ), this, SLOT( slotChanged() ) );
 
 
     QHBoxLayout *h3 = new QHBoxLayout( ml, KDialog::spacingHint() );
     h3->addStretch( 1 );
 
-    QPushButton* ok     = new QPushButton( i18n( "&OK" )    , this );
+    QPushButton* ok     = new KPushButton( KStdGuiItem::ok() , this );
     ok->setDefault(TRUE);
     h3->addWidget( ok );
 
-    QPushButton* apply  = new QPushButton( i18n( "&Apply" ) , this );
+    apply  = new KPushButton( KStdGuiItem::apply() , this );
     h3->addWidget( apply );
 
-    QPushButton* cancel = new QPushButton( i18n( "&Cancel" ), this );
+    QPushButton* cancel = new KPushButton( KStdGuiItem::cancel(), this );
     h3->addWidget( cancel );
 
     connect( browseTapeDevice, SIGNAL( clicked() ), this, SLOT( slotBrowseTapeDevice() ) );
@@ -164,7 +174,9 @@ OptionsDlg::OptionsDlg( QWidget* parent, const char* name )
     _ejectOnUnmount->setChecked( Options::instance()->getEjectOnUnmount() );
     _variableBlockSize->setChecked( Options::instance()->getVariableBlockSize() );
 
-    resize(minimumSize());
+    //resize(minimumSize());
+    apply->setEnabled( false );
+    configChanged = false;
 }
 
 OptionsDlg::~OptionsDlg()
@@ -204,9 +216,16 @@ void OptionsDlg::slotBrowseTarCommand()
     }
 }
 
+void OptionsDlg::slotChanged()
+{
+    apply->setEnabled( true );
+    configChanged = true;
+}
+
 void OptionsDlg::slotOK()
 {
-    slotApply();
+    if( configChanged )
+        slotApply();
     accept();
 }
 
@@ -237,6 +256,8 @@ void OptionsDlg::slotApply()
     Options::instance()->setVariableBlockSize( _variableBlockSize->isChecked() );
 
     Options::instance()->sync();
+    apply->setEnabled( false );
+    configChanged = false;
 }
 
 void OptionsDlg::slotCancel()
