@@ -1,4 +1,4 @@
-// $Id: VerifyDlg.cpp,v 1.23 2002/08/11 09:00:12 binner Exp $
+// $Id: VerifyDlg.cpp,v 1.23.4.1 2004/04/12 17:04:25 binner Exp $
 //
 // KDat - a tar-based DAT archiver
 // Copyright (C) 1998-2000  Sean Vyain, svyain@mail.tds.net
@@ -26,13 +26,14 @@
 
 #include <qlabel.h>
 #include <qlayout.h>
-#include <qpushbutton.h>
 #include <qfile.h>
 
 #include <kapplication.h>
 #include <kprocess.h>
 #include <klocale.h>
 #include <kdebug.h>
+#include <kpushbutton.h>
+#include <kstdguiitem.h>
 
 #include "LoggerWidget.h"
 #include "Options.h"
@@ -75,8 +76,8 @@ VerifyDlg::VerifyDlg( const QString & workingDir, int fileno, const RangeList& r
 
     resize( 500, 300 );
 
-    /* 2002-01-26 LEW: "Time remaining" was cut off in mid-"g" 
-       in BackupDlg.cpp, 
+    /* 2002-01-26 LEW: "Time remaining" was cut off in mid-"g"
+       in BackupDlg.cpp,
        so we'll provide that plus some space beyond it. */
     // const int labelWidth = 96;
     const int labelWidth = 110;
@@ -135,7 +136,7 @@ VerifyDlg::VerifyDlg( const QString & workingDir, int fileno, const RangeList& r
         _log = new LoggerWidget( i18n( "Verify log:" ), this );
     }
 
-    _ok = new QPushButton( i18n( "&OK" ), this );
+    _ok = new KPushButton( KStdGuiItem::ok(), this );
     _ok->setFixedSize( 80, _ok->sizeHint().height() );
     connect( _ok, SIGNAL( clicked() ), this, SLOT( slotOK() ) );
     _ok->setEnabled( FALSE );
@@ -145,7 +146,7 @@ VerifyDlg::VerifyDlg( const QString & workingDir, int fileno, const RangeList& r
     connect( _save, SIGNAL( clicked() ), _log, SLOT( save() ) );
     _save->setEnabled( FALSE );
 
-    _abort = new QPushButton( i18n( "&Abort" ), this );
+    _abort = new KPushButton( KStdGuiItem::cancel(), this );
     _abort->setFixedSize( 80, _abort->sizeHint().height() );
     connect( _abort, SIGNAL( clicked() ), this, SLOT( slotAbort() ) );
 
