@@ -22,10 +22,11 @@
 #include <qlayout.h>
 #include <qlineedit.h>
 #include <qlistbox.h>
-#include <qpushbutton.h>
 
 #include <kapplication.h>
 #include <kfiledialog.h>
+#include <kpushbutton.h>
+#include <kstdguiitem.h>
 
 #include "VerifyOptDlg.h"
 #include <klocale.h>
@@ -46,9 +47,9 @@ VerifyOptDlg::VerifyOptDlg( const QString & def, const QStringList& files, bool
 
     QLabel* lbl1;
     if ( _restore ) {
-        lbl1 = new QLabel( i18n( "Restore to directory:" ), this );
+        lbl1 = new QLabel( i18n( "Restore to folder:" ), this );
     } else {
-        lbl1 = new QLabel( i18n( "Verify in directory:" ), this );
+        lbl1 = new QLabel( i18n( "Verify in folder:" ), this );
     }
     lbl1->setFixedSize( lbl1->sizeHint() );
 
@@ -70,9 +71,9 @@ VerifyOptDlg::VerifyOptDlg( const QString & def, const QStringList& files, bool
     QListBox* fileList = new QListBox( this );
     fileList->insertStringList(files);
 
-    QPushButton* ok     = new QPushButton( i18n( "&OK" ), this );
+    QPushButton* ok     = new KPushButton( KStdGuiItem::ok(), this );
     ok->setFixedSize( 80, ok->sizeHint().height() );
-    QPushButton* cancel = new QPushButton( i18n( "&Cancel" ), this );
+    QPushButton* cancel = new KPushButton( KStdGuiItem::cancel(), this );
     cancel->setFixedSize( 80, cancel->sizeHint().height() );
 
     QVBoxLayout* l1 = new QVBoxLayout( this, 8, 4 );
@@ -82,7 +83,7 @@ VerifyOptDlg::VerifyOptDlg( const QString & def, const QStringList& files, bool
     l1_1->addWidget( lbl1 );
     l1_1->addWidget( _entry, 1 );
     l1_1->addWidget( browse );
-    
+
     l1->addWidget( lbl2 );
     l1->addWidget( fileList, 1 );
 
