@@ -1,8 +1,30 @@
-//////////////////////////////////////////////////////////////
-//      $Id: findf.cpp,v 1.25 2002/06/26 16:11:14 toivo Exp $
-//
-// Author: Toivo Pedaste
-//
+/* findf.cpp
+**
+** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
+**
+*/
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
+** MA 02111-1307, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
+
 #include "../config.h"
 
 #include "kpackage.h"
@@ -11,7 +33,8 @@
 #include "options.h"
 #include <klocale.h>
 #include <qlineedit.h>
-#include <qdragobject.h>
+#include <kdebug.h>
+#include <kurldrag.h>
 #include "pkgInterface.h"
 
 extern pkgInterface *kpinterface[];
@@ -140,24 +163,21 @@ void FindF::search(QListViewItem *item)
 
 void FindF::dragEnterEvent(QDragEnterEvent* e)
 {
-  e->accept(QUriDrag::canDecode(e));
+  e->accept(KURLDrag::canDecode(e));
 }
 
 void FindF::dropEvent(QDropEvent *de) // something has been dropped
 {
-  QStrList list;
-  QUriDrag::decode(de, list);
-  QString url;
+  KURL::List list;
+  if (!KURLDrag::decode(de, list) || list.isEmpty())
+     return;
 
-  const char *s = list.first();
-  KURL *u = new KURL( s );
+  const KURL &url = list.first();
 
-  if (!u->isMalformed() && (u->protocol() == "file"  )) {
-    url = u->path();
-    if (url.right(1) == "/")
-      url.truncate(url.length()-1);
-    value->setText(url);
-    doFind(url);
+  if (url.isLocalFile()) {
+    QString file = url.path(-1);
+    value->setText(file);
+    doFind(file);
   } else {
     KpMsgE(i18n("Incorrect URL type"),FALSE);
   }
