@@ -1,33 +1,58 @@
-//////////////////////////////////////////////////////////////////////
-//      $Id: kpackage.cpp,v 1.80 2002/10/09 15:19:03 toivo Exp $
-// File  : kpackage.cpp
+/* kpackage.cpp
+**
+** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
+**
 // Author: Damyan Pepper
 //         Toivo Pedaste
 //
 // See kpackage.h for more information.
-//////////////////////////////////////////////////////////////////////
+*/
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
+** MA 02111-1307, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
+
 
 #include "../config.h"
-extern "C"
-{
-#include <time.h>
-}
-#include <unistd.h>
 
 #include <qdir.h>
-#include <qdragobject.h>
+#include <qlabel.h>
+#include <qframe.h>
 
+#include <kdebug.h>
+#include <kapplication.h>
+#include <kfiledialog.h>
+#include <kprogress.h>
 #include <kurl.h>
 #include <kapplication.h>
 #include <kaccel.h>
+#include <kaction.h>
 #include <kkeydialog.h>
 #include <klocale.h>
-#include <klineeditdlg.h>
+#include <kinputdialog.h>
 #include <kglobal.h>
 #include <kiconloader.h>
 #include <kstdaction.h>
 #include <kedittoolbar.h>
 #include <kmimemagic.h>
+#include <kurldrag.h>
 
 #include "kpackage.h"
 #include "managementWidget.h"
@@ -53,7 +78,7 @@ KPKG::KPKG(KConfig *_config)
   kpackage->management->readPSeparator();
 
   // Get a nice default size
-  resize(600,400);
+  resize(760,540);
 
   setupMenu();
   disableNext();
@@ -62,33 +87,7 @@ KPKG::KPKG(KConfig *_config)
   optiondialog = new Options(this);
 
   prop_restart = false;
-
-
-  int width, height;
-  width = config->readNumEntry("Width", 760);
-  height = config->readNumEntry("Height", 540);
-
-  if( width < minimumSize().width() ) {
-    width = minimumSize().width();
-  }
-  if( height < minimumSize().height() ) {
-    height = minimumSize().height();
-  }
-
-  resize(width, height);
-
-}
-
-// Destructor
-KPKG::~KPKG()
-{
-  //   object deletion - slows down exit
-  //    delete filemenu;
-  //    delete helpmenu;
-  //    delete kp;
-  //    delete options;
-  //    delete optiondialog;
-  //    delete caches;
+  setAutoSaveSettings();
 }
 
 // Set up the menu
@@ -96,118 +95,104 @@ KPKG::~KPKG()
 void KPKG::setupMenu()
 {
 
-
-  keys = new KAccel(this);
-
   pack_open = KStdAction::open(kpackage, SLOT(fileOpen()),
-			  actionCollection());
-  pack_open->plugAccel(keys);
+			       actionCollection());
 
   recent = KStdAction::openRecent(this, SLOT(openRecent(const KURL&)),
 				  actionCollection());
   recent->loadEntries( config );
 
- pack_find = new KAction( i18n("Find &Package..."), "find",
-		       KStdAccel::key(KStdAccel::Find), kpackage,
-		       SLOT(find()), actionCollection(), "pack_find");
-  pack_find->plugAccel(keys);
+  pack_find = new KAction( i18n("Find &Package..."), "find",
+			   KStdAccel::shortcut(KStdAccel::Find), kpackage,
+			   SLOT(find()), actionCollection(), "pack_find");
 
   pack_findf = new KAction( i18n("Find &File..."), "filefind",
-		       0, kpackage,
-		       SLOT(findf()), actionCollection(), "pack_findf");
-  pack_findf->plugAccel(keys);
+			    0, kpackage,
+			    SLOT(findf()), actionCollection(), "pack_findf");
 
   kpack_reload = new KAction( i18n("&Reload"), "reload",
-		       KStdAccel::key(KStdAccel::Reload), kpackage,
-		       SLOT(reload()), actionCollection(), "kpack_reload");
-  kpack_reload->plugAccel(keys);
+			      KStdAccel::shortcut(KStdAccel::Reload), kpackage,
+			      SLOT(reload()), actionCollection(), "kpack_reload");
 
   (void) KStdAction::quit(kpackage, SLOT(fileQuit()),
-			  actionCollection())->plugAccel(keys);
+			  actionCollection());
 
   pack_prev = KStdAction::back(kpackage->management, SLOT(previous()),
-			  actionCollection(),"pack_prev");
-  pack_prev->plugAccel(keys);
+			       actionCollection(),"pack_prev");
 
   pack_next = KStdAction::forward(kpackage->management, SLOT(next()),
-			     actionCollection(),"pack_next");
-  pack_next->plugAccel(keys);
+				  actionCollection(),"pack_next");
 
   (void) (new KAction( i18n("&Expand Tree"), "ftout",
 		       0, kpackage,
-		       SLOT(expandTree()), actionCollection(), "kpack_expand"))->plugAccel(keys);
+		       SLOT(expandTree()), actionCollection(), "kpack_expand"));
 
   (void) (new KAction( i18n("&Collapse Tree"), "ftin",
 		       0, kpackage,
-		       SLOT(collapseTree()), actionCollection(), "kpack_collapse"))->plugAccel(keys);
+		       SLOT(collapseTree()), actionCollection(), "kpack_collapse"));
 
   (void) (new KAction( i18n("Clear &Marked"), QString::null,
 		       0, kpackage,
-		       SLOT(clearMarked()), actionCollection(), "kpack_clear"))->plugAccel(keys);
+		       SLOT(clearMarked()), actionCollection(), "kpack_clear"));
+
+  (void) (new KAction( i18n("Mark &All"), QString::null,
+		       0, kpackage,
+		       SLOT(markAll()), actionCollection(), "kpack_markall"));
 
   pack_install = new KAction( i18n("&Install"), QString::null,
-		       0, kpackage->management,
-		       SLOT(installSingleClicked()), actionCollection(), "install_single");
-  pack_install->plugAccel(keys);
+			      0, kpackage->management,
+			      SLOT(installSingleClicked()), actionCollection(), "install_single");
+
   pack_install->setEnabled(false);
   kpackage->management->setInstallAction(pack_install);
 
 
   pack_uninstall = new KAction( i18n("&Uninstall"), QString::null,
-		       0, kpackage->management,
-		       SLOT(uninstallSingleClicked()), actionCollection(), "uninstall_single");
-  pack_uninstall->plugAccel(keys);
+				0, kpackage->management,
+				SLOT(uninstallSingleClicked()), actionCollection(), "uninstall_single");
+
   pack_uninstall->setEnabled(false);
   kpackage->management->setUninstallAction(pack_uninstall);
 
 
   (void) (new KAction( i18n("&Install Marked"), QString::null,
 		       0, kpackage->management,
-		       SLOT(installMultClicked()), actionCollection(), "install_marked"))->plugAccel(keys);
+		       SLOT(installMultClicked()), actionCollection(), "install_marked"));
 
   (void) (new KAction( i18n("&Uninstall Marked"), QString::null,
 		       0, kpackage->management,
-		       SLOT(uninstallMultClicked()), actionCollection(), "uninstall_marked"))->plugAccel(keys);
+		       SLOT(uninstallMultClicked()), actionCollection(), "uninstall_marked"));
 
-  pack_toolbar = KStdAction::showToolbar( this, SLOT(toggleToolBar()), actionCollection());
+  setStandardToolBarMenuEnabled(true);
 
   KStdAction::configureToolbars( this, SLOT(configureToolBars()),
-				 actionCollection())->plugAccel(keys);
+				 actionCollection());
 
-  KStdAction::saveOptions( this, SLOT(saveSettings()), actionCollection())->plugAccel(keys);
+  KStdAction::saveOptions( this, SLOT(saveSettings()), actionCollection());
 
-  KStdAction::keyBindings( this, SLOT(setKeys()), actionCollection())->plugAccel(keys);
+  KStdAction::keyBindings( this, SLOT(setKeys()), actionCollection());
 
   (void) (new KAction( i18n("Configure &Kpackage..."), "configure",
 		       0, this,
-		       SLOT(setOptions()), actionCollection(), "kpack_options"))->plugAccel(keys);
+		       SLOT(setOptions()), actionCollection(), "kpack_options"));
 
-  (void) (new KAction( i18n("Clear Package &Directory Cache"), QString::null,
+  (void) (new KAction( i18n("Clear Package &Folder Cache"), QString::null,
 		       0, this,
-		       SLOT(clearDCache()), actionCollection(), "clear_dcache"))->plugAccel(keys);
+		       SLOT(clearDCache()), actionCollection(), "clear_dcache"));
 
   (void) (new KAction( i18n("Clear &Package Cache"), QString::null,
 		       0, this,
-		       SLOT(clearPCache()), actionCollection(), "clear_pcache"))->plugAccel(keys);
+		       SLOT(clearPCache()), actionCollection(), "clear_pcache"));
 
   int i;
   for (i = 0; i < kpinterfaceN; i++) {
     if (kpinterface[i]) {
-      kpinterface[i]->makeMenu(keys, actionCollection());
+      kpinterface[i]->makeMenu(actionCollection());
     }
   }
 
-  int toolPos = config->readNumEntry("ToolBarPos",KToolBar::Left);
-  int iconText = config->readNumEntry("IconText");
-  int iconSize = config->readNumEntry("IconSize",0);
-
-  keys->readSettings();
   //  urlList.setAutoDelete(TRUE);
   createGUI();
-
-  toolBar()->setBarPos((KToolBar::BarPosition)toolPos);
-  toolBar()->setIconText((KToolBar::IconText)iconText);
-  toolBar()->setIconSize(iconSize);
 }
 
 void KPKG::disableMenu()
@@ -247,24 +232,21 @@ void KPKG::openRecent(const KURL& url){
   kpackage->openNetFile( url );
 }
 
-void KPKG::add_recent_file(QString newfile){
+void KPKG::add_recent_file(const QString &newfile){
 
   KURL url = KURL(newfile);
 
   recent->addURL( url );
 }
 
-void KPKG::toggleToolBar() {
-  if(pack_toolbar->isChecked())
-    toolBar("mainToolBar")->show();
-  else
-    toolBar("mainToolBar")->hide();
+void KPKG::configureToolBars() {
+  KEditToolbar dlg(actionCollection());
+  connect(&dlg,SIGNAL(newToolbarConfig()),this,SLOT(slotNewToolbarConfig()));
+  dlg.exec();
 }
 
-void  KPKG::configureToolBars() {
-  KEditToolbar dlg(actionCollection());
-  if (dlg.exec())
-    createGUI();
+void KPKG::slotNewToolbarConfig() {
+  createGUI();
 }
 
 void KPKG::writeSettings(){
@@ -275,25 +257,11 @@ void KPKG::writeSettings(){
 
   config->setGroup("Kpackage");
 
-  config->writeEntry("Width", width());
-  config->writeEntry("Height", height());
-  config->writeEntry( "ToolBar", hide_toolbar ? "off" : "on" );
-
-  // Bars created floating don't work
-  if (toolBar()->barPos() == KToolBar::Floating)
-    config->writeEntry("ToolBarPos", (int)KToolBar::Left );
-  else
-    config->writeEntry("ToolBarPos", (int) toolBar()->barPos() );
-  config->writeEntry("IconText", (int) toolBar()->iconText() );
-  config->writeEntry("IconSize", (int) toolBar()->iconSize() );
-
   recent->saveEntries( config );
 
   kpackage->management->writeTreePos();
   kpackage->management->writeTreeType();
 
-  keys->writeSettings();
-
   config->sync();
 }
 
@@ -302,7 +270,7 @@ void KPKG::setOptions(){
 }
 
 void KPKG::setKeys(){
-  KKeyDialog::configureKeys( keys );
+  KKeyDialog::configure(actionCollection());
 }
 
 void KPKG::saveSettings(){
@@ -319,13 +287,13 @@ void KPKG::clearDCache(){
 
 void KPKG::saveProperties(KConfig *config )
 {
-    config->writeEntry("Name", kpackage->save_url.url());
+    config->writePathEntry("Name", kpackage->save_url.url());
 }
 
 
 void KPKG::readProperties(KConfig *config)
 {
-    QString entry = config->readEntry("Name"); // no default
+    QString entry = config->readPathEntry("Name"); // no default
     if (entry.isNull())
 	return;
     kpackage->openNetFiles(entry);
@@ -455,19 +423,16 @@ void KPACKAGE::reload()
 void KPACKAGE::fileOpen()		// file->quit selected from menu
 {
     KFileDialog *box;
-    //    pkgInterface *type;
 
     box = getFileDialog(i18n("Select Package"));
 
-    box->exec();
-
-    if (!box->result())   /* cancelled */
-      return;
-    if(box->selectedURL().isEmpty()) {  /* no selection */
-      return;
+    if( box->exec())
+    {
+        if(!box->selectedURL().isEmpty())
+        {
+            openNetFile( box->selectedURL() );
+        }
     }
-
-    openNetFile( box->selectedURL() );
 }
 
 void KPACKAGE::clearMarked()
@@ -475,6 +440,11 @@ void KPACKAGE::clearMarked()
   management->clearMarked(management->treeList->firstChild());
 }
 
+void KPACKAGE::markAll()
+{
+  management->markAll(management->treeList->firstChild());
+}
+
 void KPACKAGE::expandTree()
 {
   management->expandTree(management->treeList);
@@ -485,7 +455,7 @@ void KPACKAGE::collapseTree()
   management->collapseTree(management->treeList);
 }
 
-pkgInterface *KPACKAGE::pkType(QString fname)
+pkgInterface *KPACKAGE::pkType(const QString &fname)
 {
   // Get the package information for this package
   char buf[51];
@@ -604,7 +574,7 @@ QString KPACKAGE::getFileName(const KURL & url, QString &cacheName )
   QString none  = "";
   QString fname = "";
 
-  if ( url.isMalformed() )  {
+  if ( !url.isValid() )  {
     KpMsgE(i18n("Malformed URL: %1").arg(url.url()),TRUE);
   } else {
 
@@ -630,6 +600,23 @@ QString KPACKAGE::getFileName(const KURL & url, QString &cacheName )
   return fname;
 }
 
+bool KPACKAGE::isFileLocal( const KURL & url )
+{
+  QString cf;
+
+  QString f = getFileName(url, cf);
+
+  if (cf.isEmpty()) {
+    return false;
+  } else {
+    if (!f.isEmpty()) {
+      return true;
+    } else {
+      return false;
+    }
+  }
+}
+
 QString KPACKAGE::fetchNetFile( const KURL & url )
 {
 
@@ -646,21 +633,24 @@ QString KPACKAGE::fetchNetFile( const KURL & url )
     } else {
       save_url = url;
 
-      setStatus(i18n("Starting Kio"));
+      setStatus(i18n("Starting KIO"));
 
       Kio kio;
 
       if (kio.download(url, cf)) {
-	setStatus(i18n("Kio finished"));
-	QFileInfo f(cf);
-	if (!(f.exists() && f.size() > 0)) {
-	  unlink(QFile::encodeName(cf));
+	setStatus(i18n("KIO finished"));
+	QFileInfo fi(cf);
+	if (!(fi.exists() && fi.size() > 0)) {
+          unlink(QFile::encodeName(cf));
 	  return "";
 	} else {
+          CacheList cl(fi.dirPath());
+          cl.append(fi.fileName());
+          cl.write();
 	  return cf;
 	}
       } else {
-	setStatus(i18n("Kio failed"));
+	setStatus(i18n("KIO failed"));
 	return "";
       }
     }
@@ -670,12 +660,15 @@ QString KPACKAGE::fetchNetFile( const KURL & url )
 /////////////////////////////////////////////////////////////////////////
 void KPACKAGE::fileOpenUrl(){
 
-  KLineEditDlg geturl( i18n("Open Location:"), save_url.prettyURL(), this );
+  bool ok;
 
-  if ( geturl.exec() )
+  QString url = KInputDialog::getText( QString::null,
+      i18n( "Open location:" ), save_url.prettyURL(), &ok, this );
+
+  if ( ok )
     {
-      kpkg->add_recent_file(geturl.text());
-      openNetFile( geturl.text() );
+      kpkg->add_recent_file( url );
+      openNetFile( url );
     }
 }
 
@@ -693,7 +686,7 @@ void KPACKAGE::findf(){
     findialog = new FindF(this);
 }
 
-KFileDialog* KPACKAGE::getFileDialog(QString captiontext)
+KFileDialog* KPACKAGE::getFileDialog(const QString &captiontext)
 {
 
   if(!file_dialog) {
@@ -717,26 +710,19 @@ KFileDialog* KPACKAGE::getFileDialog(QString captiontext)
 
 void KPACKAGE::dragEnterEvent(QDragEnterEvent* e)
 {
-  e->accept(QUriDrag::canDecode(e));
+  e->accept(KURLDrag::canDecode(e));
 }
 
 void KPACKAGE::dropEvent(QDropEvent *de) // something has been dropped
 {
-  int i = 0;
+  KURL::List list;
+  if (!KURLDrag::decode(de, list) || list.isEmpty())
+     return;
 
-  QStrList list;
-  QUriDrag::decode(de, list);
-  QStringList urls;
-
-  for ( const char *s = list.first();
-	s != 0;
-	s = list.next(), i++ ) {
-    urls.append(s);
-  }
-  openNetFiles(urls);
+  openNetFiles(list.toStringList());
 }
 
-void KPACKAGE::setStatus(QString s)	// set the text in the status bar
+void KPACKAGE::setStatus(const QString &s)	// set the text in the status bar
 {
   status->setText(s);
   kapp->processEvents();	// refresh the screen
