@@ -1,11 +1,34 @@
-///////////////////////////////////////////////////////////////////////////////
-// $Id: main.cpp,v 1.32 2002/10/08 14:49:39 toivo Exp $	
-// File  : main.cpp
+/* main.cpp
+**
+** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
+**
 // Author: Damyan Pepper
 // Author: Toivo Pedaste
 //
 // This is the entry point to the program
-///////////////////////////////////////////////////////////////////////////////
+*/
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
+** MA 02111-1307, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
+
 #include <stdlib.h>
 
 #include "../config.h"
@@ -20,6 +43,7 @@
 #include <options.h>
 
 #include <kaboutdata.h>
+#include <kdebug.h>
 
 #include <kpTerm.h>
 #include "debInterface.h"
@@ -28,9 +52,7 @@
 #include "kissInterface.h"
 #include "slackInterface.h"
 #include "fbsdInterface.h"
-//#ifdef HAVE_RPM
 #include "rpmInterface.h"
-//#endif
 
 
 static const char *description = 
@@ -41,7 +63,7 @@ static KCmdLineOptions options[] =
    { "remote ", I18N_NOOP("Remote host for Debian APT, via SSH"), 0 },
    { "r ", 0, 0},
    { "+[Package]", I18N_NOOP("Package to install"), 0 },
-   { 0, 0, 0 }
+   KCmdLineLastOption
 };
 
 // Globals
@@ -89,17 +111,17 @@ int main(int argc, char **argv)
     kpinterface[i] = 0;
   }
 
+  kdDebug() << "Hostname=" << hostName << "\n";
+  opts = new Opts(hostName);
+
   kpinterface[j++] = new DEBDPKG();
   kpinterface[j++] = new DEBAPT();
   kpinterface[j++] = new KISS();
-  //#ifdef HAVE_RPM
   kpinterface[j++] = new RPM();
-  //#endif
   kpinterface[j++] = new fbsdInterface();
   kpinterface[j++] = new SLACK(); // Also catched BSD packages...
-
-  kdDebug() << "Hostname=" << hostName << "\n";
-  opts = new Opts(hostName);
+  
+  opts->readLaterSettings();
 
   if ( app.isRestored() ) {
     if (KPKG::canBeRestored(1)) {
