@@ -1,11 +1,34 @@
-//////////////////////////////////////////////////////////////
-// 	$Id: packageProperties.cpp,v 1.30 2002/10/08 14:49:39 toivo Exp $	
-//
-// Author: Toivo Pedaste
-//
+/* packageProperties.cpp
+**
+** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
+**
+*/
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
+** MA 02111-1307, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
+
 
 #include "../config.h"
 #include <stdio.h>
+#include <kdebug.h>
 
 #include "kpackage.h"
 #include "packageProperties.h"
@@ -156,7 +179,7 @@ void packagePropertiesWidget::changePackage(packageInfo *p)
   update();
 }
 
-void  packagePropertiesWidget::depends(QString f) {
+void  packagePropertiesWidget::depends(const QString &f) {
   //  printf("d=%s\n",f.data());
 
   int i = 0;
@@ -168,7 +191,7 @@ void  packagePropertiesWidget::depends(QString f) {
   }
 }
 
-void  packagePropertiesWidget::dor(QString f) {
+void  packagePropertiesWidget::dor(const QString &f) {
   //  printf("o=%s\n",f.data());
 
   int i = 0;
@@ -180,7 +203,7 @@ void  packagePropertiesWidget::dor(QString f) {
   }
 }
 
-void  packagePropertiesWidget::delement(QString f) {
+void  packagePropertiesWidget::delement(const QString &f) {
   int n = f.find("(");
   if (n < 0) {
     n = f.length();
