@@ -1,9 +1,30 @@
-/////////////////////////////////////////////////////////////////////////////////
-//      $Id: pkgOptions.cpp,v 1.13.4.1 2002/12/13 15:20:22 toivo Exp $
-//
-// File  : pkgOptions.cpp
-// Author: Toivo Pedaste
-//
+/* pkgOptions.cpp
+**
+** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
+**
+*/
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
+** MA 02111-1307, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
+
 
 #include "../config.h"
 // qt headers
@@ -14,16 +35,20 @@
 #include <kglobalsettings.h>
 #include <klistview.h>
 #include <kseparator.h>
+#include <kdebug.h>
+#include <kpushbutton.h>
+#include <kstdguiitem.h>
 
 #include "pkgOptions.h"
 #include "managementWidget.h"
 #include "debInterface.h"
 #include "kpackage.h"
+#include "options.h"
 
 ///////////////////////////////////////////////////////////////////////////
 ///////////////////////////////////////////////////////////////////////////
 
-pkgOptions::pkgOptions(pkgInterface *pki, QWidget *parent)
+pkgOptions::pkgOptions(pkgInterface *pki, QWidget *parent, const QString &caption)
   :  KDialog(parent,0,TRUE)
 {
   //  setFrameStyle(QFrame::Raised | QFrame::Panel);
@@ -32,8 +57,7 @@ pkgOptions::pkgOptions(pkgInterface *pki, QWidget *parent)
 
   hide();
 
-  notModified = TRUE;
-  running = FALSE;
+  setCaption(caption);
 }
 
 // Destructor
@@ -60,7 +84,7 @@ void pkgOptions::setupWidgets(QPtrList<param> &pars)
   //  title->update();
 
   installButton = new QPushButton(insType,this);
-  cancelButton = new QPushButton(i18n("Cancel"),this);
+  cancelButton = new KPushButton(KStdGuiItem::cancel(),this);
   // count number of buttons
   bnumber = pars.count();
 
@@ -72,9 +96,12 @@ void pkgOptions::setupWidgets(QPtrList<param> &pars)
     Boxs[i]->setChecked(p->init);
   }
 
+  Keep = new QCheckBox(i18n("Keep this window"), this);
+
   // Connections
   connect(installButton,SIGNAL(clicked()),SLOT(pkginstallButtonClicked()));
   connect(cancelButton,SIGNAL(clicked()),SLOT(cancelButtonClicked()));
+  connect(Keep, SIGNAL(toggled(bool)), SLOT(keepToggle(bool)));
 
   // Do the layout
   vlayout = new QBoxLayout(this, QBoxLayout::TopToBottom, marginHint(), spacingHint());
@@ -99,6 +126,13 @@ void pkgOptions::setupWidgets(QPtrList<param> &pars)
       }
       layout->addWidget(new KSeparator(KSeparator::HLine, this), 2);
 
+      QBoxLayout *slayout = new QBoxLayout(layout, QBoxLayout::LeftToRight);
+      slayout->addStretch(1);
+      slayout->addWidget(Keep, 1);
+      slayout->addStretch(1);
+
+      layout->addWidget(new KSeparator(KSeparator::HLine, this), 2);
+
       QBoxLayout *buttons = new QBoxLayout(QBoxLayout::LeftToRight);
       layout->addLayout(buttons);
 
@@ -108,12 +142,10 @@ void pkgOptions::setupWidgets(QPtrList<param> &pars)
     }
     {
       term = new kpTerm(kpty,this);
-      hlayout->addWidget(term);
+      hlayout->addWidget(term, 1000);
     }
   }
-  resize(minimumSize());
-  //  hlayout->activate();
-  //  layout->activate();
+  resize(800, 400);
 }
 
 void pkgOptions::setup(packageInfo *p, QString type) {
@@ -125,7 +157,7 @@ void pkgOptions::setup(packageInfo *p, QString type) {
 void pkgOptions::setup(QPtrList<packageInfo> *pl, QString)
 {
  QString s;
- notModified = TRUE;
+ modified = FALSE;
 
  packList = pl;
 
@@ -166,10 +198,6 @@ void pkgOptions::setup(QPtrList<packageInfo> *pl, QString)
     }
   }
 
-  //  title->setText(i18n("%1: 1 %2 Package", "%1: %n %2 Packages", plist.count())
-  //                 .arg(insType).arg(pkgInt->name));
-  // Doesn't compile for me
-
  if (plist.count() == 1) {
    s = i18n("%1: 1 %2 Package").arg(insType).arg(pkgInt->name);
  } else {
@@ -178,10 +206,10 @@ void pkgOptions::setup(QPtrList<packageInfo> *pl, QString)
  title->setText(s);
 
   for (QStringList::Iterator pit = plist.begin(); pit != plist.end(); ++pit ) {
-    kdDebug() << "P=" << *pit << "\n";
+    //    kdDebug() << "P=" << *pit << "\n";
     new QListViewItem(packages, *pit);
   }
-  cancelButton->setText(i18n("Cancel"));
+  cancelButton->setGuiItem(KStdGuiItem::cancel());
 }
 
 // install button has been clicked....so install the package
@@ -189,7 +217,7 @@ void pkgOptions::pkginstallButtonClicked()
 {
   int i;
   QStringList r;
-  notModified = FALSE;
+  modified = TRUE;
 
   // Collect data from check boxes
   int installFlags = 0;
@@ -207,7 +235,7 @@ void pkgOptions::pkginstallButtonClicked()
   if (s == "0=") {
     cancelButtonClicked();
   } else if (s.left(2) == "1=") {
-    term->textIn(s.mid(2));
+    term->textIn(s.mid(2), true);
   } else {
     connect(term,SIGNAL(result(QStringList &, int)),
 	 this,SLOT(slotResult(QStringList &, int)));
@@ -216,7 +244,7 @@ void pkgOptions::pkginstallButtonClicked()
 
     if (term->run(s, r)) {
       running = TRUE;
-      cancelButton->setText(i18n("Cancel"));
+      cancelButton->setGuiItem(KStdGuiItem::cancel());
     } else {
       reset();
     }
@@ -239,7 +267,7 @@ void pkgOptions::slotSearch(QListViewItem *item)
 
 void pkgOptions::reset() {
   installButton->setEnabled(TRUE);
-  cancelButton->setText(i18n("Done"));
+  cancelButton->setGuiItem(KGuiItem(i18n("Done")));  //clear icon
   disconnect(term,SIGNAL(result(QStringList &, int)),
 	 this,SLOT(slotResult(QStringList &, int)));
   running = FALSE;
@@ -248,29 +276,72 @@ void pkgOptions::reset() {
 void pkgOptions::slotResult(QStringList &, int ret)
 {
   reset();
-  if (ret == 0 && !test) {
+  if (ret == 0 && !test && !keep) {
     term->done();
     accept();
   }
 }
 
-void pkgOptions::cancelButtonClicked()
-{
+void pkgOptions::terminate() {
   if (running) {
     term->cancel();
     reset();
   }
+}
+
+void pkgOptions::cancelButtonClicked()
+{
+  terminate();
   term->done();
-  if (notModified || test)
+
+  if (!modified || test)
     reject();
   else
     accept();
 }
 
+void pkgOptions::hideEvent ( QHideEvent *h ) {
+  terminate();
+
+  QWidget::hideEvent (h);
+}
+
+void pkgOptions::showEvent ( QShowEvent *e ) {
+  //  kdDebug() << "SHOW\n";
+  getKeep();
+
+  modified = FALSE;
+  running = FALSE;
+
+  QWidget::showEvent(e);
+}
+
+void pkgOptions::keepToggle(bool kp)
+{
+  //  kdDebug() << "KEEP " << kp << "\n";
+
+  KConfig *config = kapp->config();
+
+  config->setGroup("Kpackage");
+  config->writeEntry("keepIWin", kp);
+
+  keep = kp;
+}
+
+void pkgOptions::getKeep()
+{
+    KConfig *config = kapp->config();
+    config->setGroup("Kpackage");
+    keep =  config->readBoolEntry("keepIWin", true);
+  kdDebug() << "getKEEP " << keep << "\n";
+    Keep->setChecked(keep);
+
+}
+
 ///////////////////////////////////////////////////////////////////////////
 ///////////////////////////////////////////////////////////////////////////
 pkgOptionsI::pkgOptionsI(pkgInterface *pkg, QWidget *parent):
-  pkgOptions(pkg, parent)
+  pkgOptions(pkg, parent, i18n("Install"))
 {
   insType = i18n("Install");
   installer = TRUE;
@@ -285,7 +356,7 @@ QString pkgOptionsI::doPackages(int installFlags, QPtrList<packageInfo> *p, bool
 ///////////////////////////////////////////////////////////////////////////
 ///////////////////////////////////////////////////////////////////////////
 pkgOptionsU::pkgOptionsU(pkgInterface *pkg, QWidget *parent):
-  pkgOptions(pkg, parent)
+  pkgOptions(pkg, parent, i18n("Uninstall"))
 {
   insType = i18n("Uninstall");
   installer = FALSE;
