@@ -1,8 +1,30 @@
-//////////////////////////////////////////////////////////////
-//      $Id: search.cpp,v 1.15 2002/08/28 15:44:29 kalass Exp $
-//
-// Author: Toivo Pedaste
-//
+/* search.cpp
+**
+** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
+**
+*/
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
+** MA 02111-1307, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
+
 #include "../config.h"
 
 #include "kpackage.h"
@@ -11,6 +33,8 @@
 #include <klocale.h>
 #include <qlineedit.h>
 #include <qcheckbox.h>
+#include <qframe.h>
+#include <qgroupbox.h>
 
 Search::Search(QWidget *parent, const char * name)
     : KDialogBase(parent, name, false,
@@ -81,7 +105,7 @@ void Search::ok_slot()
   }
   if (pkg == 0)
     KpMsg(i18n("Note"),
-	  i18n("%1 was not found").arg(to_find),TRUE);
+	  i18n("%1 was not found.").arg(to_find),TRUE);
 }
 
 void Search::done_slot()
