@@ -1,16 +1,38 @@
-//////////////////////////////////////////////////////////////
-//      $Id: slackInterface.cpp,v 1.39 2002/08/15 16:06:16 binner Exp $
-//
-// Author: Toivo Pedaste
-//
+/* slackInterface.cpp
+**
+** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
+**
+*/
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
+** MA 02111-1307, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
+
 #include "../config.h"
 
 #include <unistd.h>
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <fcntl.h>
+#include <ctype.h>
 
-#include <time.h>
 #include <setjmp.h>
 
 #include <qdir.h>
@@ -20,6 +42,7 @@
 #include <kurl.h>
 #include <kglobal.h>
 #include <kiconloader.h>
+#include <kdebug.h>
 
 #include "packageInfo.h"
 #include "slackInterface.h"
@@ -59,16 +82,16 @@ SLACK::SLACK():pkgInterface()
   procMsg = i18n("Kpackage: Waiting on SLACK");
 
   locatedialog = new Locations(i18n("Location of Slackware Package Archives"));
-  locatedialog->pLocations(1, 1, this,  i18n("I"),
+  locatedialog->pLocations(1, 1, this,  i18n("Install location", "I"),
   "Slackware", "*.TXT *.txt *.tgz *.tar.gz",
   i18n("Location of a 'PACKAGES.TXT' File for Extended Information"));
-  locatedialog->pLocations(4, 1, this,  i18n("P"),
+  locatedialog->pLocations(4, 1, this,  i18n("Packages file", "P"),
   "Slackware", "*.tgz *.tar.gz",
   i18n("Location of 'PACKAGES.TXT' File for Slackware Distribution"),
-  i18n("Location of Base Directory of Slackware Distribution"));
-  locatedialog->dLocations(2, 6, this,  i18n("D"),
+  i18n("Location of Base Folder of Slackware Distribution"));
+  locatedialog->dLocations(2, 6, this,  i18n("Folders", "F"),
   "Slackware", "*.tgz *.tar.gz",
-  i18n("Location of Directories Containing Slackware Packages"));
+  i18n("Location of Folders Containing Slackware Packages"));
 
   connect(locatedialog,SIGNAL(returnVal(LcacheObj *)),
   	  this,SLOT(setAvail(LcacheObj *)));
@@ -364,7 +387,9 @@ packageInfo *SLACK::collectInfo(const char *_inp, int insState)
 	  xstr++;
 	}
 
-	qstrcpy(str, QString(str).lower().ascii());
+	for( int i = 0; str[ i ] != '\0'; ++i )
+            str[ i ] = tolower( str[ i ] );
+
 	if (*str == ' ')
 	  str++;
 
@@ -461,6 +486,21 @@ packageInfo *SLACK::collectInfo(const char *_inp, int insState)
 
 //////////////////////////////////////////////////////////////////////////////
 //////////////////////////////////////////////////////////////////////////////
+
+QStringList SLACK::getChangeLog(packageInfo *) {
+  return 0;
+}
+
+bool SLACK::filesTab(packageInfo *) {
+  return TRUE;
+}
+
+bool SLACK::changeTab(packageInfo *) {
+    return FALSE;
+}
+
+//////////////////////////////////////////////////////////////////////////////
+
 QStringList SLACK::getFileList(packageInfo *p)
 {
   char linebuf[1024];
@@ -636,9 +676,8 @@ void SLACK::setLocation()
 //////////////////////////////////////////////////////////////////////////////
 void SLACK::setAvail(LcacheObj *slist)
 {
-  if (packageLoc)
     delete packageLoc;
-  packageLoc = slist;
+    packageLoc = slist;
 }
 
 //////////////////////////////////////////////////////////////////////////////
