@@ -1,9 +1,29 @@
-//////////////////////////////////////////////////////////////
-//      $Id: slackInterface.h,v 1.20 2002/06/07 11:44:59 coolo Exp $
-//
-// Author: Toivo Pedaste
-//
-//////////////////////////////////////////////////////////////
+/* slackInterface.h
+**
+** Copyright (C) 1999,2000 Toivo Pedaste <toivo@ucs.uwa.edu.au>
+**
+*/
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
+** MA 02111-1307, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
 
 #ifndef SLACK_IFACE_H
 #define SLACK_IFACE_H
@@ -32,6 +52,13 @@ public:
   packageInfo *getPackageInfo(char mode, const QString &name,
 			      const QString &version);
   QStringList getFileList(packageInfo *p);
+  QStringList getChangeLog(packageInfo *p);
+
+  bool filesTab(packageInfo *p);
+  // If files tab is to be enabled
+
+  bool changeTab(packageInfo *p);
+  // If change log tab is to be enabled
 
   QStringList FindFile(const QString &name);
   bool parseName(const QString& name, QString *n, QString *v);
