@@ -30,7 +30,7 @@
 #include <qgroupbox.h>
 #include <qaccel.h>
 #include <qscrollbar.h>
-#include <qtextview.h>
+#include <qtextedit.h>
 #include <qcstring.h>
 #include <qclipboard.h>
 #include <qheader.h>
@@ -82,9 +82,9 @@ KSVContent::KSVContent (KPopupMenu* openWithMenu, KSVTopLevel* parent, const cha
 	mScriptBox (0L),
     mRunlevels (new QVBox*[ksv::runlevelNumber]),
 	mOrigin (0L),
-    mOpenWithMenu (openWithMenu)
+    mOpenWithMenu (openWithMenu), m_buffer( QCString() )
 {
-  setOpaqueResize (true);
+  setOpaqueResize( KGlobalSettings::opaqueResize() );
 
   KXMLGUIFactory* factory = parent->factory();
   mItemMenu = static_cast<KPopupMenu*> (factory->container ("item_menu", parent));
@@ -309,7 +309,9 @@ void KSVContent::initLList()
 		   this, SLOT(fwdUndoAction(KSVAction*)));
 
   // add text-diplay widget
-  textDisplay = new QTextView (QString::null, QString::null, this, "TextDisplayWidget");
+  textDisplay = new QTextEdit( QString::null, QString::null, this, "TextDisplayWidget" );
+  textDisplay->setTextFormat( Qt::RichText );
+  textDisplay->setReadOnly( true );
 
   for (int i = 0; i < ksv::runlevelNumber; ++i)
 	{
@@ -609,8 +611,8 @@ void KSVContent::stopService (const QString& path)
   *_proc << path << "stop";
 
   connect(_proc, SIGNAL(processExited(KProcess*)), this, SLOT(slotExitedProcess(KProcess*)));
-  connect(_proc, SIGNAL(receivedStdout(KProcess*, char*, int)), this, SLOT(slotOutput(KProcess*, char*, int)));
-  connect(_proc, SIGNAL(receivedStderr(KProcess*, char*, int)), this, SLOT(slotErr(KProcess*, char*, int)));
+  connect(_proc, SIGNAL(receivedStdout(KProcess*, char*, int)), this, SLOT(slotOutputOrError(KProcess*, char*, int)));
+  connect(_proc, SIGNAL(receivedStderr(KProcess*, char*, int)), this, SLOT(slotOutputOrError(KProcess*, char*, int)));
 
   // refresh textDisplay
   appendLog(i18n("** <stop>Stopping</stop> <cmd>%1</cmd> **<br/>").arg(path),
@@ -635,8 +637,8 @@ void KSVContent::startService (const QString& path)
   *_proc << path << "start";
 
   connect(_proc, SIGNAL(processExited(KProcess*)), this, SLOT(slotExitedProcess(KProcess*)));
-  connect(_proc, SIGNAL(receivedStdout(KProcess*, char*, int)), this, SLOT(slotOutput(KProcess*, char*, int)));
-  connect(_proc, SIGNAL(receivedStderr(KProcess*, char*, int)), this, SLOT(slotErr(KProcess*, char*, int)));
+  connect(_proc, SIGNAL(receivedStdout(KProcess*, char*, int)), this, SLOT(slotOutputOrError(KProcess*, char*, int)));
+  connect(_proc, SIGNAL(receivedStderr(KProcess*, char*, int)), this, SLOT(slotOutputOrError(KProcess*, char*, int)));
 
   // refresh textDisplay
   appendLog(i18n("** <start>Starting</start> <cmd>%1</cmd> **<br/>").arg(path),
@@ -668,15 +670,15 @@ void KSVContent::restartService ()
 
 void KSVContent::restartService (const QString& path)
 {
-  // stopping
+  // restarting
   KProcess *_proc = new KProcess();
   _proc->clearArguments();
 
-  *_proc << path << "stop";
+  *_proc << path << "restart";
 
   connect(_proc, SIGNAL(processExited(KProcess*)), this, SLOT(slotExitDuringRestart(KProcess*)));
-  connect(_proc, SIGNAL(receivedStdout(KProcess*, char*, int)), this, SLOT(slotOutput(KProcess*, char*, int)));
-  connect(_proc, SIGNAL(receivedStderr(KProcess*, char*, int)), this, SLOT(slotErr(KProcess*, char*, int)));
+  connect(_proc, SIGNAL(receivedStdout(KProcess*, char*, int)), this, SLOT(slotOutputOrError(KProcess*, char*, int)));
+  connect(_proc, SIGNAL(receivedStderr(KProcess*, char*, int)), this, SLOT(slotOutputOrError(KProcess*, char*, int)));
 
   // refresh textDisplay
   appendLog(i18n("** Re-starting <cmd>%1</cmd> **</br>").arg(path),
@@ -688,19 +690,10 @@ void KSVContent::restartService (const QString& path)
   emit sigRun(path + i18n(" restart"));
 }
 
-void KSVContent::slotOutput( KProcess*, char* _buffer, int _buflen) {
+void KSVContent::slotOutputOrError( KProcess*, char* _buffer, int _buflen) {
   if (_buflen > 0) {
-    QCString buffer = QCString( _buffer, _buflen + 1 );
-    buffer[_buflen]='\0';
-    appendLog(buffer, buffer);
-  }
-}
-
-void KSVContent::slotErr( KProcess*, char* _buffer, int _buflen) {
-  if (_buflen > 0) {
-    QCString buffer = QCString( _buffer, _buflen + 1);
-    buffer[_buflen]='\0';
-    appendLog(buffer, buffer);
+    m_buffer += QCString( _buffer, _buflen + 1 );
+    appendLog( m_buffer );
   }
 }
 
@@ -747,8 +740,8 @@ void KSVContent::slotExitDuringRestart( KProcess* proc )
   proc->clearArguments();
 
   connect(proc, SIGNAL(processExited(KProcess*)), this, SLOT(slotExitedProcess(KProcess*)));
-  connect(proc, SIGNAL(receivedStdout(KProcess*, char*, int)), this, SLOT(slotOutput(KProcess*, char*, int)));
-  connect(proc, SIGNAL(receivedStderr(KProcess*, char*, int)), this, SLOT(slotErr(KProcess*, char*, int)));
+  connect(proc, SIGNAL(receivedStdout(KProcess*, char*, int)), this, SLOT(slotOutputOrError(KProcess*, char*, int)));
+  connect(proc, SIGNAL(receivedStderr(KProcess*, char*, int)), this, SLOT(slotOutputOrError(KProcess*, char*, int)));
 
   proc->start(KProcess::NotifyOnExit, KProcess::AllOutput);
 }
@@ -807,6 +800,15 @@ void KSVContent::appendLog (const QString& rich, const QString& plain)
   textDisplay->append (rich);
 }
 
+void KSVContent::appendLog(const QCString& _buffer)
+{
+    QStringList _lines = QStringList::split( "\n", QString::fromLocal8Bit( _buffer ) );
+    for ( QStringList::Iterator it = _lines.begin(); it != _lines.end(); ++it )
+        appendLog( *it, *it );
+
+    m_buffer = QCString();
+}
+
 const QString& KSVContent::log () const
 {
   return mLogText;
@@ -935,8 +937,8 @@ void KSVContent::multiplexEnabled (bool val)
 	int choice = KMessageBox::warningYesNo
 	  (kapp->mainWidget(),
 	   i18n ("<p>You have specified that your system's init "  \
-		 "scripts are located in the directory "           \
-		 "<tt><b>%1</b></tt>, but this directory does not "\
+		 "scripts are located in the folder "           \
+		 "<tt><b>%1</b></tt>, but this folder does not "\
 		 "exist. You probably selected the wrong "         \
 		 "distribution during configuration.</p> "         \
 		 "<p>If you reconfigure %2, it may be possible to "\
@@ -951,7 +953,7 @@ void KSVContent::multiplexEnabled (bool val)
 	   .arg (kapp->aboutData()->programName())
 	   .arg (kapp->aboutData()->programName())
 	   .arg (kapp->aboutData()->programName()),
-	   i18n("Directory Does Not Exist"));
+	   i18n("Folder Does Not Exist"));
 
 	if ( choice == KMessageBox::Yes )
 	{
