@@ -42,7 +42,8 @@ KSVPreferences::KSVPreferences (QWidget* parent)
    */
   QFrame* lafPage = addPage (i18n ("Look & Feel"), QString::null, DesktopIcon ("colorize", 32));
   mLookAndFeel = new KSVLookAndFeel (lafPage);
-  
+  connect( mLookAndFeel, SIGNAL( configChanged() ), this, SLOT( slotChanged() ) );
+
   QVBoxLayout* lafLayout = new QVBoxLayout (lafPage);
   lafLayout->addWidget (mLookAndFeel);
 
@@ -51,16 +52,16 @@ KSVPreferences::KSVPreferences (QWidget* parent)
 //    */
 //   QFrame* colorPage = addPage (i18n("Colors"), QString::null, DesktopIcon ("colorize", 32));
 //   mColorConfig = new KSVColorConfig(colorPage);
-  
+
 //   QVBoxLayout* colorLayout = new QVBoxLayout(colorPage);
 //   colorLayout->addWidget(mColorConfig);
-  
+
 //   /**
 //    * Fonts Page
 //    */
 //   QFrame* fontPage = addPage (i18n("Fonts"), QString::null, DesktopIcon ("fonts", 32));
 //   mFontConfig = new KSVFontConfig(fontPage);
-  
+
 //   QVBoxLayout* fontLayout = new QVBoxLayout (fontPage);
 //   fontLayout->addWidget(mFontConfig);
 
@@ -69,16 +70,18 @@ KSVPreferences::KSVPreferences (QWidget* parent)
    */
   QFrame* pathPage = addPage (i18n ("Paths"), QString::null, DesktopIcon ("kfm", 32));
   mPathConfig = new KSVPathConfig(pathPage);
+  connect( mPathConfig, SIGNAL( configChanged() ), this, SLOT( slotChanged() ) );
 
   QVBoxLayout *pathLayout = new QVBoxLayout (pathPage);
-  pathLayout->addWidget (mPathConfig);  
+  pathLayout->addWidget (mPathConfig);
 
   /**
    * Miscellaneous Page
-   */ 
+   */
   QFrame* miscPage = addPage (i18n ("Miscellaneous"), i18n("Settings Not Fitting Anywhere Else"),
                               DesktopIcon ("misc", 32));
   mMiscConfig = new KSVMiscConfig(miscPage);
+  connect( mMiscConfig, SIGNAL( configChanged() ), this, SLOT( slotChanged() ) );
 
   QVBoxLayout *miscLayout = new QVBoxLayout (miscPage);
   miscLayout->addWidget (mMiscConfig);
@@ -86,12 +89,20 @@ KSVPreferences::KSVPreferences (QWidget* parent)
   connect (mMiscConfig->mShowAll, SIGNAL (clicked()), this, SLOT (showAllMessages()));
 
   reReadConfig();
+  enableButton( Apply, false );
+  configChanged = false;
 }
 
 KSVPreferences::~KSVPreferences ()
 {
 }
 
+void KSVPreferences::slotChanged()
+{
+  enableButton( Apply, true );
+  configChanged = true;
+}
+
 void KSVPreferences::reReadConfig()
 {
   mPathConfig->mRunlevelPath->setText(mConfig->runlevelPath());
@@ -118,35 +129,38 @@ void KSVPreferences::slotCancel ()
 void KSVPreferences::slotApply ()
 {
   if (checkPaths())
+  {
     setConfig();
+    enableButton( Apply, false );
+    configChanged = false;
+  }
 }
 
 bool KSVPreferences::checkPaths ()
 {
   bool result = true;
-    
+
   if (!QDir(mPathConfig->mServicesPath->text()).exists())
     result = (KMessageBox::warningContinueCancel(this,
-                                                 i18n ("The service directory you specified does "
+                                                 i18n ("The service folder you specified does "
                                                        "not exist.\n"
                                                        "You can continue if you want to, "
                                                        "or you can click Cancel "
-                                                       "to select a new directory."),
+                                                       "to select a new folder."),
                                                  i18n ("Warning"))
               != KMessageBox::Cancel);
 
   if (!QDir(mPathConfig->mRunlevelPath->text()).exists())
-    result = result 
+    result = result
       && (KMessageBox::warningContinueCancel(this,
-                                             i18n ("The runlevel directory you specified does "
+                                             i18n ("The runlevel folder you specified does "
                                                    "not exist.\n"
                                                    "You can continue if you want to, "
                                                    "or you can click Cancel "
-                                                   "to select a new directory."),
-                                             i18n ("Warning"),
-                                             i18n ("Continue"))
+                                                   "to select a new folder."),
+                                             i18n ("Warning"))
           != KMessageBox::Cancel);
-  
+
   return result;
 }
 
@@ -195,7 +209,7 @@ void KSVPreferences::setConfig ()
     if (sp != mConfig->scriptPath())
       {
         mConfig->setScriptPath (sp);
-        
+
         emit updateServicesPath ();
       }
   }
@@ -206,11 +220,11 @@ void KSVPreferences::setConfig ()
     if (rp != mConfig->runlevelPath ())
       {
         mConfig->setRunlevelPath (rp);
-        
+
         emit updateRunlevelsPath ();
       }
   }
-  
+
   // if necessary, update miscellaneous settings
   {
     mConfig->setShowMessage (ksv::RunlevelsReadOnly,
@@ -225,7 +239,7 @@ void KSVPreferences::setConfig ()
     QColor ns = newSelected();
     QColor cn = changedNormal();
     QColor cs = changedSelected();
-    
+
     if (nn != mConfig->newNormalColor() ||
         ns != mConfig->newSelectedColor() ||
         cn != mConfig->changedNormalColor() ||
@@ -235,16 +249,16 @@ void KSVPreferences::setConfig ()
         mConfig->setNewSelectedColor (ns);
         mConfig->setChangedNormalColor (cn);
         mConfig->setChangedSelectedColor (cs);
-        
+
         emit updateColors ();
       }
   }
-  
+
   // if necessary, update fonts
   {
     const QFont& sf = mLookAndFeel->serviceFont();
     const QFont& ns = mLookAndFeel->numberFont();
-    
+
     if (sf != mConfig->serviceFont() || ns != mConfig->numberFont())
       {
         mConfig->setServiceFont (sf);
@@ -258,7 +272,7 @@ void KSVPreferences::setConfig ()
 void KSVPreferences::showAllMessages ()
 {
   KMessageBox::enableAllMessages ();
-  
+
   // update checkboxes
   reReadMessages();
 }
