@@ -5,7 +5,7 @@
     Copyright (C) 1997-2000 Peter Putzer
                             putzer@kde.org
 
-	$Id: TopWidget.cpp,v 1.110.2.1 2003/05/19 02:52:56 mueller Exp $
+	$Id: TopWidget.cpp,v 1.117.2.1 2004/04/12 17:04:25 binner Exp $
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of version 2 of the GNU General Public License
@@ -18,7 +18,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+    Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */
 
 /****************************************************************
@@ -228,7 +228,7 @@ void KSVTopLevel::initActions ()
 
   mFileSaveLog = KStdAction::save (this, SLOT(slotSaveLog()), coll, "ksysv_save_log");
   mFileSaveLog->setText (i18n("Save &Log..."));
-  mFileSaveLog->setAccel (Key_L+CTRL);
+  mFileSaveLog->setShortcut (Key_L+CTRL);
   mFileSaveLog->setEnabled (false);
 
   // disabled due to complexity
@@ -306,8 +306,8 @@ bool KSVTopLevel::queryExit() {
     res = KMessageBox::warningYesNo(kapp->mainWidget(),
 				    i18n("There are unsaved changes. Are you sure you want to quit?"),
 				    i18n("Quit"),
-				    i18n("&Quit"),
-				    i18n("&Cancel"));
+				    KStdGuiItem::quit(),
+				    KStdGuiItem::cancel());
 
   }
 
@@ -323,7 +323,7 @@ void KSVTopLevel::slotClearChanges()
 				 i18n("Do you really want to revert all unsaved changes?"),
 				 i18n("Revert Configuration"),
 				 i18n("&Revert"),
-				 i18n("&Cancel")))
+				 KStdGuiItem::cancel()))
     {
       mUndoList->undoAll();
 	  mRedoList->clear();
@@ -338,8 +338,8 @@ void KSVTopLevel::slotAcceptChanges() {
 				     "make your system hang on startup.\n"
 				     "Do you wish to continue?"),
 				i18n("Save Configuration"),
-				i18n("&Save"),
-				i18n("&Cancel")))
+				KStdGuiItem::save(),
+				KStdGuiItem::cancel()))
     {
       mView->slotWriteSysV();
       initView();
@@ -412,7 +412,7 @@ void KSVTopLevel::initStatusBar()
                                  "when you use the <strong>Save Options command</strong>.</p>"));
   QToolTip::add (visBox, i18n ("Show only the selected runlevels"));
 
-  new QLabel (i18n(" Show runlevels: "), visBox, "visLabel");
+  new QLabel (i18n("Show runlevels:"), visBox, "visLabel");
   for (int i = 0; i < ksv::runlevelNumber; ++i)
 	{
 	  QString label; label.setNum (i);
@@ -794,7 +794,7 @@ void KSVTopLevel::printLog()
   prt->setDocName(kapp->aboutData()->programName() + " Log File");
   prt->setCreator(kapp->aboutData()->programName());
 
-  if (prt->setup(this))
+  if (prt->setup(this, i18n("Print Log File")))
     {
       KBusyManager::self()->setBusy (true);
 
@@ -819,7 +819,7 @@ void KSVTopLevel::printLog()
 
         y += tmp_h;
 
-        QSimpleRichText rdate (i18n("<h3>Printed on %1</h3><br/><br/>").arg(QDateTime::currentDateTime().toString()),
+        QSimpleRichText rdate (i18n("<h3>Printed on %1</h3><br/><br/>").arg(KGlobal::locale()->formatDateTime(QDateTime::currentDateTime())),
                                QFont("times"), QString::null, ksv::styleSheet(),
                                QMimeSourceFactory::defaultFactory());
         rdate.setWidth (&p, width);
@@ -1019,17 +1019,20 @@ KActionCollection* KSVTopLevel::filteredActions ()
 
 void KSVTopLevel::configureKeys ()
 {
-  KKeyDialog::configureKeys (filteredActions(), xmlFile(), true, this);
+  KKeyDialog::configure (filteredActions(), this, true);
 }
 
 void KSVTopLevel::configureToolbars ()
 {
-  KEditToolbar* dlg = new KEditToolbar (filteredActions(), xmlFile(), true, this);
+  KEditToolbar dlg(filteredActions(), xmlFile(), true, this);
+  connect(&dlg, SIGNAL( newToolbarConfig() ), this, SLOT( slotNewToolbarConfig() ));
+  dlg.exec();
+}
 
-  if (dlg->exec())
-    createGUI (xmlFile());
-
-  delete dlg;
+void KSVTopLevel::slotNewToolbarConfig()
+{
+  createGUI (xmlFile());
+  setTools(mConfig->showTools());
 }
 
 void KSVTopLevel::dispatchEditService (bool val)
