@@ -1,9 +1,31 @@
+/*
+ *  Copyright (c) 1998 Denis Perchine <dyp@perchine.com>
+ *  Maintained by Adriaan de Groot <groot@kde.org>
+ *
+ *  This program is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU General Public
+ *  License version 2 as published by the Free Software Foundation.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Library General Public License
+ *  along with this library; see the file COPYING.LIB.  If not, write to
+ *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ *  Boston, MA 02111-1307, USA.
+ **/
+
 #ifndef _KU_GLOBALS_H_
 #define _KU_GLOBALS_H_
 
 #define _KU_VERSION "1.0"
 
-#include "../config.h"
+#include <config.h>
+#ifdef HAVE_PATHS_H
+#include <paths.h>
+#endif
 #include <kconfig.h>
 #include "kerror.h"
 
@@ -16,13 +38,17 @@ extern int is_shadow;
 
 #define KU_BACKUP_EXT ".bak"
 
-#define MAIL_SPOOL_DIR "/var/spool/mail"
+#ifdef HAVE_PATHS_H
+  #define SHELL_FILE _PATH_SHELLS
+  #define MAIL_SPOOL_DIR _PATH_MAILDIR
+#else
+  #define SHELL_FILE "/etc/shells"
+  #define MAIL_SPOOL_DIR "/var/spool/mail"
+#endif
 
 #if defined(__FreeBSD__) || defined(__bsdi__)
   #undef HAVE_SHADOW
   #include <pwd.h>
-  #include <paths.h>
-  #define SHELL_FILE _PATH_SHELLS
   #define PASSWORD_FILE _PATH_MASTERPASSWD
   #define PASSWORD_FILE_MASK S_IRUSR | S_IWUSR
   #define PWMKDB _PATH_PWD_MKDB" -p "PASSWORD_FILE
@@ -31,7 +57,6 @@ extern int is_shadow;
   #define SKELDIR "/usr/share/skel"
   #define SKEL_FILE_PREFIX "dot"
 #else
-  #define SHELL_FILE "/etc/shells"
   #define PASSWORD_FILE "/etc/passwd"
   #define PASSWORD_FILE_MASK S_IRUSR | S_IWUSR | S_IRGRP | S_IROTH
   #define GROUP_FILE "/etc/group"
