@@ -1,3 +1,22 @@
+/*
+ *  Copyright (c) 1998 Denis Perchine <dyp@perchine.com>
+ *  Maintained by Adriaan de Groot <groot@kde.org>
+ *
+ *  This program is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU General Public
+ *  License version 2 as published by the Free Software Foundation.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Library General Public License
+ *  along with this library; see the file COPYING.LIB.  If not, write to
+ *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ *  Boston, MA 02111-1307, USA.
+ **/
+
 #ifndef _KUSER_H_
 #define _KUSER_H_
 
@@ -183,7 +202,7 @@ public:
   ~KUsers();
   KUser *lookup(const QString & name);
   KUser *lookup(uid_t uid);
-  uid_t first_free();
+  int first_free();
 
   bool load();
 
@@ -211,8 +230,8 @@ protected:
   uid_t sdw_uid;
   gid_t sdw_gid;
 
-  QPtrList<KUser> u;
-  QPtrList<KUser> du;
+  QPtrList<KUser> allUsers;
+  QPtrList<KUser> usersToDelete;
 
   bool doCreate();
   bool doDelete();
