@@ -1,3 +1,22 @@
+/*
+ *  Copyright (c) 1998 Denis Perchine <dyp@perchine.com>
+ *  Maintained by Adriaan de Groot <groot@kde.org>
+ *
+ *  This program is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU General Public
+ *  License version 2 as published by the Free Software Foundation.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Library General Public License
+ *  along with this library; see the file COPYING.LIB.  If not, write to
+ *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ *  Boston, MA 02111-1307, USA.
+ **/
+
 #define _KU_MAIN
 #include "mainView.h"
 
@@ -12,7 +31,7 @@
 #include <qsplitter.h>
 #include <qfile.h>
 
-#include <klineeditdlg.h>
+#include <kinputdialog.h>
 #include <ktoolbar.h>
 #include <kiconloader.h>
 #include <kmessagebox.h>
@@ -104,8 +123,11 @@ void mainView::useredit() {
 void mainView::userdel() {
   KUser *user = lbusers->getCurrentUser();
 
+  if (!user)
+    return;
+
   delUser dlg(user, this);
-  
+
   if (!dlg.exec())
      return;
 
@@ -121,10 +143,10 @@ void mainView::userdel() {
 
   changed = true;
 
-  config->setGroup("template"); 
+  config->setGroup("template");
   if (!config->readBoolEntry("userPrivateGroup", KU_USERPRIVATEGROUP))
     return;
-    
+
   const QString &userName = user->getName();
   KGroup *group = 0;
 
@@ -170,20 +192,21 @@ void mainView::useradd() {
   tq = new Quota(tk->getUID(), FALSE);
 #endif // _KU_QUOTA
 
-  KLineEditDlg dlg(i18n("Enter user name:"), QString::null, this);
-  dlg.setCaption(i18n("Add User"));
-  
-  if (!dlg.exec())  {
+  bool ok;
+  QString name = KInputDialog::getText( i18n( "Add User" ),
+      i18n( "Enter user name:" ), QString::null, &ok, this );
+
+  if (!ok)  {
     delete tk;
 #ifdef _KU_QUOTA
     delete tq;
 #endif
     return;
   }
-  tk->setName(dlg.text());
+  tk->setName(name);
 
-  if (kug->getUsers().lookup(dlg.text())) {
-    KMessageBox::error( 0, i18n("User with name %1 already exists.").arg(dlg.text()) );
+  if (kug->getUsers().lookup(name)) {
+    KMessageBox::error( 0, i18n("User with name %1 already exists.").arg(name) );
     delete tk;
 #ifdef _KU_QUOTA
     delete tq;
@@ -192,8 +215,8 @@ void mainView::useradd() {
   }
 
   config->setGroup("template");
-  tk->setShell(config->readEntry("shell", QString::fromLatin1("/bin/bash")));
-  tk->setHomeDir(config->readEntry("homeBase", QFile::decodeName(KU_HOMEPREFIX))+
+  tk->setShell(config->readPathEntry("shell", QString::fromLatin1("/bin/sh")));
+  tk->setHomeDir(config->readPathEntry("homeBase", QFile::decodeName(KU_HOMEPREFIX))+
   	QString::fromLatin1("/")+tk->getName());
   tk->setGID(config->readNumEntry("gid"));
   tk->setFullName(config->readEntry("p_fname"));
@@ -237,7 +260,7 @@ void mainView::useradd() {
     tq = 0;
   }
 #endif // _KU_QUOTA
-  
+
 #ifdef _KU_QUOTA
   addUser au(tk, tq, this, "userin");
 #else
@@ -283,7 +306,7 @@ void mainView::useradd() {
 void mainView::save() {
   if (!changed)
     return;
-    
+
   kug->getUsers().save();
   kug->getGroups().save();
 #ifdef _KU_QUOTA
@@ -299,17 +322,17 @@ bool mainView::queryClose()
 {
   if (!changed)
     return true;
-    
+
   int result = KMessageBox::warningYesNoCancel(0, i18n("Would you like to save your changes?"),
                                i18n("Data Was Modified"),
-                               i18n("&Save"), i18n("&Discard Changes"));
+                               KStdGuiItem::save(), KStdGuiItem::discard());
 
   if (result == KMessageBox::Cancel)
     return false;
-    
+
   if (result == KMessageBox::Yes)
     save();
-    
+
   return true;
 }
 
@@ -325,8 +348,8 @@ void mainView::properties() {
   eddlg.setCaption(i18n("Edit Defaults"));
 
   config->setGroup("template");
-  eddlg.setShell(config->readEntry("shell", QString::fromLatin1("/bin/bash")));
-  eddlg.setHomeBase(config->readEntry("homeBase", QString::fromLatin1("/home")));	
+  eddlg.setShell(config->readEntry("shell", QString::fromLatin1("/bin/sh")));
+  eddlg.setHomeBase(config->readEntry("homeBase", QString::fromLatin1("/home")));
   eddlg.setCreateHomeDir(config->readBoolEntry("createHomeDir", true));
   eddlg.setCopySkel(config->readBoolEntry("copySkel", true));
   eddlg.setUserPrivateGroup(config->readBoolEntry("userPrivateGroup", KU_USERPRIVATEGROUP));
@@ -343,8 +366,8 @@ void mainView::properties() {
   if (eddlg.exec() != 0)
   {
     config->setGroup("template");
-    config->writeEntry("shell", eddlg.getShell());
-    config->writeEntry("homeBase", eddlg.getHomeBase());
+    config->writePathEntry("shell", eddlg.getShell());
+    config->writePathEntry("homeBase", eddlg.getHomeBase());
     config->writeEntry("createHomeDir", eddlg.getCreateHomeDir());
     config->writeEntry("copySkel", eddlg.getCopySkel());
     config->writeEntry("userPrivateGroup", eddlg.getUserPrivateGroup());
@@ -378,7 +401,7 @@ void mainView::userSelected() {
   KUser *tmpKU;
 
   tmpKU =  lbusers->getCurrentUser();
-  if (!tmpKU) 
+  if (!tmpKU)
     return;
 
 #ifdef _KU_QUOTA
@@ -391,7 +414,7 @@ void mainView::userSelected() {
       return;
     }
   }
-  
+
   propdlg editUser(tmpKU, tmpQ, this, "userin");
 #else
   propdlg editUser(tmpKU, this, "userin");
@@ -414,7 +437,7 @@ void mainView::grpadd() {
 
   KGroup *tk = new KGroup();
   tk->setGID(gid);
-  
+
   grpnamedlg gd(*tk, this);
   if (gd.exec() == 0) {
     delete tk;
