@@ -1,3 +1,22 @@
+/*
+ *  Copyright (c) 1998 Denis Perchine <dyp@perchine.com>
+ *  Maintained by Adriaan de Groot <groot@kde.org>
+ *
+ *  This program is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU General Public
+ *  License version 2 as published by the Free Software Foundation.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Library General Public License
+ *  along with this library; see the file COPYING.LIB.  If not, write to
+ *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ *  Boston, MA 02111-1307, USA.
+ **/
+
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
@@ -98,9 +117,11 @@ Mounts::Mounts() {
     if (!CORRECT_FSTYPE((const char *)mt->mnt_fstype))
       continue;
 
-    quotafilename = QString("%1%2%3")
+    QString sep = (mt->mnt_mountp[strlen(mt->mnt_mountp) - 1] == '/')  ? 
+	QString::null : QString::fromLatin1("/");
+    quotafilename = QString::fromLatin1("%1%2%3")
                           .arg(QString::fromLatin1(mt->mnt_mountp))
-                          .arg(QString::fromLatin1((mt->mnt_mountp[strlen(mt->mnt_mountp) - 1] == '/') ? "" : "/"))
+                          .arg(sep)
                           .arg(QString::fromLatin1(_KU_QUOTAFILENAME));
 #elif defined(BSD)
   while ((mt=getfsent()) != NULL) {
@@ -110,7 +131,7 @@ Mounts::Mounts() {
       continue;
     quotafilename = QString::fromLatin1("%1%2%3")
                           .arg(QString::fromLatin1(mt->fs_file))
-                          .arg((mt->fs_file[strlen(mt->fs_file) -1] == '/') ? 
+                          .arg((mt->fs_file[strlen(mt->fs_file) -1] == '/') ?
 			  	QString::null : QString::fromLatin1("/"))
 			  .arg(QString::fromLatin1(_KU_QUOTAFILENAME));
 #elif defined(_AIX)
