@@ -1,4 +1,21 @@
-// $Id: propdlg.cpp,v 1.63.2.1 2003/07/07 06:39:42 aseigo Exp $
+/*
+ *  Copyright (c) 1998 Denis Perchine <dyp@perchine.com>
+ *  Maintained by Adriaan de Groot <groot@kde.org>
+ *
+ *  This program is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU General Public
+ *  License version 2 as published by the Free Software Foundation.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Library General Public License
+ *  along with this library; see the file COPYING.LIB.  If not, write to
+ *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ *  Boston, MA 02111-1307, USA.
+ **/
 
 #include "globals.h"
 
@@ -26,7 +43,7 @@
 #include <qdatetm.h>
 #endif
 
-static void addRow(QWidget *parent, QGridLayout *layout, int row, QWidget *widget, 
+static void addRow(QWidget *parent, QGridLayout *layout, int row, QWidget *widget,
                    const QString &label, const QString &what, bool two_column=true)
 {
    QLabel *lab = new QLabel(widget, label, parent);
@@ -44,7 +61,7 @@ static void addRow(QWidget *parent, QGridLayout *layout, int row, QWidget *widge
       layout->addWidget(widget, row, 1);
 }
 
-KDateWidget *propdlg::addDateGroup(QWidget *parent, QGridLayout *layout, int row, 
+KDateWidget *propdlg::addDateGroup(QWidget *parent, QGridLayout *layout, int row,
 	const QString &title, int days)
 {
     KDateWidget *date;
@@ -59,8 +76,9 @@ KDateWidget *propdlg::addDateGroup(QWidget *parent, QGridLayout *layout, int row
        days = 0;
     }
     date = new KDateWidget(QDate(1970,1,1).addDays(days), parent);
+    label->setBuddy(date);
     layout->addMultiCellWidget(date, row, row, 1, 2);
-    
+
     QCheckBox *date_disabled = new QCheckBox(parent);
     date_disabled->setText(i18n("Never"));
     layout->addWidget(date_disabled, row, 3);
@@ -73,7 +91,7 @@ KDateWidget *propdlg::addDateGroup(QWidget *parent, QGridLayout *layout, int row
     return date;
 }
 
-KIntSpinBox *propdlg::addDaysGroup(QWidget *parent, QGridLayout *layout, int row, 
+KIntSpinBox *propdlg::addDaysGroup(QWidget *parent, QGridLayout *layout, int row,
 	const QString &title, const QString &title2, int nr_of_days, bool never)
 {
     KIntSpinBox *days;
@@ -82,6 +100,7 @@ KIntSpinBox *propdlg::addDaysGroup(QWidget *parent, QGridLayout *layout, int row
     layout->addWidget(label, row, 0, AlignRight);
 
     days = new KIntSpinBox(parent);
+    label->setBuddy(days);
     days->setSuffix(i18n(" days"));
     days->setMaxValue(32767);
     if (never)
@@ -95,7 +114,7 @@ KIntSpinBox *propdlg::addDaysGroup(QWidget *parent, QGridLayout *layout, int row
     }
     days->setValue(nr_of_days);
     layout->addWidget(days, row, 1);
-    
+
     label = new QLabel(title2, parent);
     layout->addMultiCellWidget(label, row, row, 2, 3);
 
@@ -109,11 +128,11 @@ propdlg::propdlg(KUser *AUser, Quota *AQuota, QWidget *parent, const char *name,
 #else
 propdlg::propdlg(KUser *AUser, QWidget *parent, const char *name, int)
 #endif
- : KDialogBase(Tabbed, i18n("User Properties"), 
+ : KDialogBase(Tabbed, i18n("User Properties"),
 	Ok | Cancel, Ok, parent, name, true),
  user(AUser)
 #ifdef _KU_QUOTA
- , quota(AQuota) 
+ , quota(AQuota)
 #endif
 #ifdef EXTENDED_GECOS_BSD
  , leexpire(0L)
@@ -150,16 +169,16 @@ propdlg::propdlg(KUser *AUser, QWidget *parent, const char *name, int)
 
     leid = new QLineEdit(frame);
 //    whatstr = i18n("WHAT IS THIS: User Id");
-    addRow(frame, layout, row++, leid, i18n("User ID:"), whatstr);
+    addRow(frame, layout, row++, leid, i18n("&User ID:"), whatstr);
     connect(leid, SIGNAL(textChanged(const QString &)), this, SLOT(changed()));
 
-    pbsetpwd = new QPushButton(i18n("Set Password..."), frame);
+    pbsetpwd = new QPushButton(i18n("Set &Password..."), frame);
     layout->addWidget(pbsetpwd, 0, 2);
     QObject::connect(pbsetpwd, SIGNAL(clicked()), this, SLOT(setpwd()));
 
     lefname = new QLineEdit(frame);
 //    whatstr = i18n("WHAT IS THIS: Full Name");
-    addRow(frame, layout, row++, lefname, i18n("Full name:"), whatstr);
+    addRow(frame, layout, row++, lefname, i18n("Full &name:"), whatstr);
     QObject::connect(lefname, SIGNAL(textChanged(const QString &)), this, SLOT(changed()));
 
     leshell = new QComboBox(true, frame);
@@ -172,45 +191,45 @@ propdlg::propdlg(KUser *AUser, QWidget *parent, const char *name, int)
     QObject::connect(leshell, SIGNAL(activated(const QString &)), this, SLOT(changed()));
     QObject::connect(leshell, SIGNAL(textChanged(const QString &)), this, SLOT(changed()));
 //    whatstr = i18n("WHAT IS THIS: Login Shell");
-    addRow(frame, layout, row++, leshell, i18n("Login shell:"), whatstr);
+    addRow(frame, layout, row++, leshell, i18n("&Login shell:"), whatstr);
 
     lehome = new QLineEdit(frame);
     QObject::connect(lehome, SIGNAL(textChanged(const QString &)), this, SLOT(changed()));
 //    whatstr = i18n("WHAT IS THIS: Home Directory");
-    addRow(frame, layout, row++, lehome, i18n("Home directory:"), whatstr);
+    addRow(frame, layout, row++, lehome, i18n("&Home folder:"), whatstr);
 
 #ifdef EXTENDED_GECOS_BSD
     // FreeBSD appears to use the comma separated fields in the GECOS entry
     // differently than Linux.
-    leoffice = new QLineEdit(frame);  
+    leoffice = new QLineEdit(frame);
     QObject::connect(leoffice, SIGNAL(textChanged(const QString &)), this, SLOT(changed()));
 //    whatstr = i18n("WHAT IS THIS: Office");
-    addRow(frame, layout, row++, leoffice, i18n("Office:"), whatstr);
+    addRow(frame, layout, row++, leoffice, i18n("&Office:"), whatstr);
 
     leophone = new QLineEdit(frame);
     QObject::connect(leophone, SIGNAL(textChanged(const QString &)), this, SLOT(changed()));
 //    whatstr = i18n("WHAT IS THIS: Office Phone");
-    addRow(frame, layout, row++, leophone, i18n("Office Phone:"), whatstr);
+    addRow(frame, layout, row++, leophone, i18n("Offi&ce Phone:"), whatstr);
 
     lehphone = new QLineEdit(frame);
     QObject::connect(lehphone, SIGNAL(textChanged(const QString &)), this, SLOT(changed()));
 //    whatstr = i18n("WHAT IS THIS: Home Phone");
-    addRow(frame, layout, row++, lehphone, i18n("Home Phone:"), whatstr);
+    addRow(frame, layout, row++, lehphone, i18n("Ho&me Phone:"), whatstr);
 #else
     leoffice1 = new QLineEdit(frame);
     QObject::connect(leoffice1, SIGNAL(textChanged(const QString &)), this, SLOT(changed()));
 //    whatstr = i18n("WHAT IS THIS: Office1");
-    addRow(frame, layout, row++, leoffice1, i18n("Office #1:"), whatstr);
+    addRow(frame, layout, row++, leoffice1, i18n("&Office #1:"), whatstr);
 
     leoffice2 = new QLineEdit(frame);
     QObject::connect(leoffice2, SIGNAL(textChanged(const QString &)), this, SLOT(changed()));
 //    whatstr = i18n("WHAT IS THIS: Office2");
-    addRow(frame, layout, row++, leoffice2, i18n("Office #2:"), whatstr);
+    addRow(frame, layout, row++, leoffice2, i18n("O&ffice #2:"), whatstr);
 
     leaddress = new QLineEdit(frame);
     QObject::connect(leaddress, SIGNAL(textChanged(const QString &)), this, SLOT(changed()));
 //    whatstr = i18n("WHAT IS THIS: Address");
-    addRow(frame, layout, row++, leaddress, i18n("Address:"), whatstr);
+    addRow(frame, layout, row++, leaddress, i18n("&Address:"), whatstr);
 #endif
     frontrow = row;
   }
@@ -226,19 +245,19 @@ propdlg::propdlg(KUser *AUser, QWidget *parent, const char *name, int)
     leslstchg = new QLabel(frame);
     leslstchg->setText(KGlobal::locale()->formatDate(lastChange));
     addRow(frame, layout, row++, leslstchg, i18n("Last password change:"), QString::null, true);
- 
-    layout->addMultiCellWidget(new KSeparator(KSeparator::HLine, frame), row, row, 0, 3);
-    row++;
-
-    lesmin = addDaysGroup(frame, layout, row++, i18n("Password may not be changed before"), i18n("after last password change."), user->getMin(), false);
-    lesmax = addDaysGroup(frame, layout, row++, i18n("Password expires"), i18n("after last password change."), user->getMax());
-    leswarn = addDaysGroup(frame, layout, row++, i18n("Issue expire warning"), i18n("before password expires."), user->getWarn());
-    lesinact = addDaysGroup(frame, layout, row++, i18n("Account will be disabled"), i18n("after expiration of password."), user->getInactive());
 
     layout->addMultiCellWidget(new KSeparator(KSeparator::HLine, frame), row, row, 0, 3);
     row++;
 
-    lesexpire = addDateGroup(frame, layout, row++, i18n("Account will expire on:"), user->getExpire()); 
+    lesmin = addDaysGroup(frame, layout, row++, i18n("Password may &not be changed before"), i18n("after last password change."), user->getMin(), false);
+    lesmax = addDaysGroup(frame, layout, row++, i18n("Password &expires"), i18n("after last password change."), user->getMax());
+    leswarn = addDaysGroup(frame, layout, row++, i18n("&Issue expire warning"), i18n("before password expires."), user->getWarn());
+    lesinact = addDaysGroup(frame, layout, row++, i18n("Account will be &disabled"), i18n("after expiration of password."), user->getInactive());
+
+    layout->addMultiCellWidget(new KSeparator(KSeparator::HLine, frame), row, row, 0, 3);
+    row++;
+
+    lesexpire = addDateGroup(frame, layout, row++, i18n("&Account will expire on:"), user->getExpire());
   }
 #endif
 
@@ -250,7 +269,7 @@ propdlg::propdlg(KUser *AUser, QWidget *parent, const char *name, int)
 
     leqmnt = new QComboBox(false, frame);
 //    whatstr = i18n("WHAT IS THIS: Select filesystem");
-    addRow(frame, layout, 0, leqmnt, i18n("Filesystem with quotas:"), whatstr, false);
+    addRow(frame, layout, 0, leqmnt, i18n("&Filesystem with quotas:"), whatstr, false);
 
     leqmnt->clear();
 
@@ -263,7 +282,7 @@ propdlg::propdlg(KUser *AUser, QWidget *parent, const char *name, int)
       QGroupBox *group = new QGroupBox( frame );
       layout->addMultiCellWidget(group, 1, 1, 0, 1);
       group->setTitle(i18n("Disk Space"));
-      QGridLayout *groupLayout = new QGridLayout(group, 6, 2, marginHint(), spacingHint()); 
+      QGridLayout *groupLayout = new QGridLayout(group, 6, 2, marginHint(), spacingHint());
       groupLayout->addRowSpacing(0, group->fontMetrics().lineSpacing());
       groupLayout->setColStretch(0,1);
       int row = 1;
@@ -272,24 +291,24 @@ propdlg::propdlg(KUser *AUser, QWidget *parent, const char *name, int)
       leqfs->setValidator(new QIntValidator(group));
       QObject::connect(leqfs, SIGNAL(textChanged(const QString &)), this, SLOT(qchanged()));
 //      whatstr = i18n("WHAT IS THIS: Disk space soft quota");
-      addRow(group, groupLayout, row++, leqfs, i18n("Disk space soft quota:"), whatstr, false);
+      addRow(group, groupLayout, row++, leqfs, i18n("Disk space &soft quota:"), whatstr, false);
 
       leqfh = new QLineEdit(group);
       leqfh->setValidator(new QIntValidator(group));
       QObject::connect(leqfh, SIGNAL(textChanged(const QString &)), this, SLOT(qchanged()));
 //      whatstr = i18n("WHAT IS THIS: Disk space hard quota");
-      addRow(group, groupLayout, row++, leqfh, i18n("Disk space hard quota:"), whatstr, false);
+      addRow(group, groupLayout, row++, leqfh, i18n("Disk space &hard quota:"), whatstr, false);
 
       leqfcur = new QLabel(group);
 //      whatstr = i18n("WHAT IS THIS: Disk usage");
-      addRow(group, groupLayout, row++, leqfcur, i18n("Disk space in use:"), whatstr, false);
+      addRow(group, groupLayout, row++, leqfcur, i18n("Disk space in &use:"), whatstr, false);
 
 #ifndef BSD
       leqft = new QLineEdit(group);
       leqft->setValidator(new QIntValidator(group));
       QObject::connect(leqft, SIGNAL(textChanged(const QString &)), this, SLOT(qchanged()));
 //      whatstr = i18n("WHAT IS THIS: Time limit allowed for soft quota");
-      addRow(group, groupLayout, row++, leqft, i18n("Grace period:"), whatstr, false);
+      addRow(group, groupLayout, row++, leqft, i18n("&Grace period:"), whatstr, false);
 #endif
     }
 
@@ -298,7 +317,7 @@ propdlg::propdlg(KUser *AUser, QWidget *parent, const char *name, int)
       QGroupBox *group = new QGroupBox( frame );
       layout->addMultiCellWidget(group, 2, 2, 0, 1);
       group->setTitle(i18n("Number of Files"));
-      QGridLayout *groupLayout = new QGridLayout(group, 6, 2, marginHint(), spacingHint()); 
+      QGridLayout *groupLayout = new QGridLayout(group, 6, 2, marginHint(), spacingHint());
       groupLayout->addRowSpacing(0, group->fontMetrics().lineSpacing());
       groupLayout->setColStretch(0,1);
       int row = 1;
@@ -307,24 +326,24 @@ propdlg::propdlg(KUser *AUser, QWidget *parent, const char *name, int)
       leqis->setValidator(new QIntValidator(group));
       QObject::connect(leqis, SIGNAL(textChanged(const QString &)), this, SLOT(qchanged()));
 //      whatstr = i18n("WHAT IS THIS: File number soft quota");
-      addRow(group, groupLayout, row++, leqis, i18n("File number soft quota:"), whatstr, false);
+      addRow(group, groupLayout, row++, leqis, i18n("File &number soft quota:"), whatstr, false);
 
       leqih = new QLineEdit(group);
       leqih->setValidator(new QIntValidator(group));
       QObject::connect(leqih, SIGNAL(textChanged(const QString &)), this, SLOT(qchanged()));
 //      whatstr = i18n("WHAT IS THIS: File number hard quota");
-      addRow(group, groupLayout, row++, leqih, i18n("File number hard quota:"), whatstr, false);
+      addRow(group, groupLayout, row++, leqih, i18n("File num&ber hard quota:"), whatstr, false);
 
       leqicur = new QLabel(group);
 //      whatstr = i18n("WHAT IS THIS: File number usage");
-      addRow(group, groupLayout, row++, leqicur, i18n("Number of files in use:"), whatstr, false);
+      addRow(group, groupLayout, row++, leqicur, i18n("Numbe&r of files in use:"), whatstr, false);
 
 #ifndef BSD
       leqit = new QLineEdit(group);
       leqit->setValidator(new QIntValidator(group));
       QObject::connect(leqit, SIGNAL(textChanged(const QString &)), this, SLOT(qchanged()));
 //      whatstr = i18n("WHAT IS THIS: Time limit allowed for file number soft quota");
-      addRow(group, groupLayout, row++, leqit, i18n("Grace period:"), whatstr, false);
+      addRow(group, groupLayout, row++, leqit, i18n("Grac&e period:"), whatstr, false);
 #endif
     }
   }
@@ -338,19 +357,19 @@ propdlg::propdlg(KUser *AUser, QWidget *parent, const char *name, int)
 
 //    whatstr = i18n("WHATSTHIS: Primary Group");
     cbpgrp = new QComboBox(false, frame, "cbpgrp");
-    addRow(frame, layout, row++, cbpgrp, i18n("Primary group:"), whatstr, false);
+    addRow(frame, layout, row++, cbpgrp, i18n("&Primary group:"), whatstr, false);
     QObject::connect(cbpgrp, SIGNAL(activated(const QString &)), this, SLOT(setpgroup(const QString &)));
 
     lstgrp = new KListView(frame);
-    lstgrp->setFullWidth(); // Single column, full widget width.
+    lstgrp->setFullWidth(true); // Single column, full widget width.
     lstgrp->addColumn(i18n("Groups User '%1' Belongs To").arg(user->getName()));
 //    QString whatstr = i18n("Select the groups that this user belongs to.");
     QWhatsThis::add(lstgrp, whatstr);
     layout->addMultiCellWidget(lstgrp, row, row, 0, 1);
-    row++;    
-    QObject::connect(lstgrp, SIGNAL(clicked(QListViewItem *)), this, SLOT(gchanged())); 
+    row++;
+    QObject::connect(lstgrp, SIGNAL(clicked(QListViewItem *)), this, SLOT(gchanged()));
   }
-  
+
 #ifdef EXTENDED_GECOS_BSD
   // Tab5: extended BSD tab
   {
@@ -363,7 +382,7 @@ propdlg::propdlg(KUser *AUser, QWidget *parent, const char *name, int)
 //    whatstr = i18n("WHAT IS THIS: Login class");
     addRow(frame, layout, row++, leclass, i18n("Login class:"), whatstr, true);
 
-    leexpire = addDateGroup(frame, layout, row++, i18n("Account will expire after:"), user->getExpire()); 
+    leexpire = addDateGroup(frame, layout, row++, i18n("Account will expire after:"), user->getExpire());
   }
 #endif
 
@@ -448,7 +467,7 @@ void propdlg::gchanged() {
 }
 
 void propdlg::save() {
-  
+
   user->setUID(leid->text().toInt());
   user->setFullName(lefname->text());
 
@@ -461,7 +480,7 @@ void propdlg::save() {
   user->setHomePhone(lehphone->text());
   user->setClass(leclass->text());
 
-  // date() returns days since the epoch if a date is specified	
+  // date() returns days since the epoch if a date is specified
   // which we convert to seconds since the epoch.
   // date() returns 0 if the `never expires' box is checked which
   // ends up being converted to 0 seconds which is what we need.
@@ -684,11 +703,11 @@ void propdlg::slotOk() {
       return;
     }
   }
-  
+
   QString newshell;
   if (leshell->currentItem() != 0)
     newshell = leshell->currentText();
-  
+
   if (oldshell != newshell)
   {
     if (!checkShell(newshell)) {
@@ -702,12 +721,12 @@ void propdlg::slotOk() {
       		i18n("Do &Not Add"));
       	if (result == KMessageBox::Cancel)
       	  return;
-      	
+
       	if (result == KMessageBox::Yes)
       	  addShell(newshell);
     }
   }
-    
+
   if (check())
     accept();
   else
