@@ -1,18 +1,26 @@
+/*
+ *  Copyright (c) 1998 Denis Perchine <dyp@perchine.com>
+ *  Maintained by Adriaan de Groot <groot@kde.org>
+ *
+ *  This program is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU General Public
+ *  License version 2 as published by the Free Software Foundation.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Library General Public License
+ *  along with this library; see the file COPYING.LIB.  If not, write to
+ *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ *  Boston, MA 02111-1307, USA.
+ **/
+
 #ifdef _KU_QUOTA
 
 #include "globals.h"
 
-#ifdef HAVE_LINUX_QUOTA_H
-#  ifndef QUOTACTL_IN_LIBC
-#    include <syscall.h>
-
-int quotactl(int cmd, const char * special, int id, caddr_t addr) {
-  return syscall(SYS_quotactl, cmd, special, id, addr);
-}
-
-#  endif
-#endif
-
 #ifdef _AIX
 #include <jfs/quota.h>
 extern "C" int quotactl (const char* path, int cmd, int id, const char* addr);
@@ -150,7 +158,7 @@ void QuotaMnt::setitime(long data) {
 #define _KU_SETQUOTA QCMD(Q_SETQUOTA, USRQUOTA)
 #endif
 
-static int doQuotaCtl(int ACmd, uint AUID, const MntEnt *m, struct dqblk *dq) {
+static int doQuotaCtl(int ACmd, uint AUID, const MntEnt *m, STRUCT_DQBLK *dq) {
 #ifdef _KU_UFS_QUOTA
   int fd;
   struct quotctl qctl;
@@ -182,15 +190,21 @@ static int doQuotaCtl(int ACmd, uint AUID, const MntEnt *m, struct dqblk *dq) {
 }
 
 static QuotaMnt *getQuotaMnt(uint AUID, const MntEnt *m) {
-  struct dqblk dq;
+  STRUCT_DQBLK dq;
 
   int res = doQuotaCtl(_KU_GETQUOTA, AUID, m, &dq);
 
   if (res == 0)
     return new QuotaMnt(
+#ifdef HAVE_IF_DQBLK
+      dq.dqb_curspace,
+      dq.dqb_bsoftlimit,
+      dq.dqb_bhardlimit,
+#else
       dbtob(dq.dqb_curblocks)/1024,
       dbtob(dq.dqb_bsoftlimit)/1024,
       dbtob(dq.dqb_bhardlimit)/1024,
+#endif
       _KU_CURINODES,
       _KU_ISOFTLIMIT,
       _KU_IHARDLIMIT,
@@ -204,11 +218,17 @@ static QuotaMnt *getQuotaMnt(uint AUID, const MntEnt *m) {
 }
 
 static void setQuotaMnt(uint AUID, const MntEnt *m, QuotaMnt *qm) {
-  struct dqblk dq;
+  STRUCT_DQBLK dq;
 
+#ifdef HAVE_IF_DQBLK
+  dq.dqb_curspace  = qm->getfcur();
+  dq.dqb_bsoftlimit = qm->getfsoft();
+  dq.dqb_bhardlimit = qm->getfhard();
+#else
   dq.dqb_curblocks  = btodb(qm->getfcur() * 1024);
   dq.dqb_bsoftlimit = btodb(qm->getfsoft() * 1024);
   dq.dqb_bhardlimit = btodb(qm->getfhard() * 1024);
+#endif
   _KU_CURINODES     = qm->geticur();
   _KU_ISOFTLIMIT    = qm->getisoft();
   _KU_IHARDLIMIT    = qm->getihard();
