@@ -1,11 +1,22 @@
-/**********************************************************************
+/*
+ *  Copyright (c) 1998 Denis Perchine <dyp@perchine.com>
+ *  Maintained by Adriaan de Groot <groot@kde.org>
+ *
+ *  This program is free software; you can redistribute it and/or
+ *  modify it under the terms of the GNU General Public
+ *  License version 2 as published by the Free Software Foundation.
+ *
+ *  This library is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ *  Library General Public License for more details.
+ *
+ *  You should have received a copy of the GNU Library General Public License
+ *  along with this library; see the file COPYING.LIB.  If not, write to
+ *  the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ *  Boston, MA 02111-1307, USA.
+ **/
 
-	--- Qt Architect generated file ---
-
-	File: userDefaultsPage.cpp
-	Last generated: Mon Oct 12 00:56:45 1998
-
- *********************************************************************/
 
 
 #include <kapplication.h>
@@ -42,7 +53,7 @@ userDefaultsPage::userDefaultsPage(
 
   tl->addStretch(1);
 
-  l = new QLabel(i18n("Base of home directories:"), this);
+  l = new QLabel(i18n("Base of home folders:"), this);
   l->setFixedSize(l->sizeHint());
   tl->addWidget(l, 0, AlignLeft);
   home=new QLineEdit(this);
@@ -51,11 +62,11 @@ userDefaultsPage::userDefaultsPage(
 
   tl->addStretch(2);
 
-  createHomeDir = new QCheckBox(i18n("Create home dir"), this);
+  createHomeDir = new QCheckBox(i18n("Create home folder"), this);
   createHomeDir->setFixedSize(createHomeDir->sizeHint());
   tl->addWidget(createHomeDir, 0, AlignLeft);
 
-  copySkel = new QCheckBox(i18n("Copy skeleton to home dir"), this);
+  copySkel = new QCheckBox(i18n("Copy skeleton to home folder"), this);
   copySkel->setFixedSize(copySkel->sizeHint());
   tl->addWidget(copySkel, 0, AlignLeft);
 
