@@ -1,3 +1,31 @@
+/* lilo.cc
+**
+** Copyright (C) 2000,2001 by Bernhard Rosenkraenzer
+**
+** Contributions by A. Seigo and W. Bastian.
+**
+*/
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
+** MA 02111-1307, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
 #include "lilo.h"
 #include "Disks.h"
 #include "Files.h"
@@ -21,11 +49,7 @@ bool liloimage::isLinux() const {
 
 liloimage *liloimages::find(String const &s) const
 {
-	String t = s;
-
-	/* escape any metacharacters */
-	t = t.replace("{", "\\{", true);
-	t = t.replace("}", "\\}", true);
+	String t = String::escapeForRegExp(s);
 
 	String regex="^[ \t]*label[ \t]*=[ \t]*\"?" + t + "\"?[ \t]*";
 	for(const_iterator it=begin(); it!=end(); it++) {
@@ -210,9 +234,9 @@ bool liloconf::probe()
 			if(!access(compr, F_OK))
 				continue;
 		}
-		String version=(*it).regex("(test-?|pre-?)?(([0-9]+(\\.|-)?(test-?|pre-?|ac-?|bero-?)?)+[0-9]+)+(smp|BOOT|enterprise)?");
+		String version=(*it).regex("(test-?|pre-?)?([0-9]\\.[0-9]\\.[0-9]+)(-?[0-9A-Za-z]+)*");
 		String label=version;
-		if(version.empty()) // Yippie! - not a Red Hat Linux kernel
+		if(version.empty()) // not a recognized kernel
 			version="linux";
 		
 		if (label.empty())
@@ -467,11 +491,7 @@ void liloconf::addOther(String const &name, String const &partition, bool const
 }
 void liloconf::remove(String const &label)
 {
-	String t = label;
-
-	/* escape any metacharacters */
-	t = t.replace("{", "\\{", true);
-	t = t.replace("}", "\\}", true);
+	String t = String::escapeForRegExp(label);
 
 	String regex="[ \t]*label[ \t]*=[ \t]*\"?"+t+"\"?[ \t]*";
 	for(liloimages::iterator it=images.begin(); it!=images.end(); it++) {
@@ -483,11 +503,7 @@ void liloconf::remove(String const &label)
 }
 void liloconf::removeKernel(String const &kernel)
 {
-	String t = kernel;
-
-	/* escape any metacharacters */
-	t = t.replace("{", "\\{", true);
-	t = t.replace("}", "\\}", true);
+	String t = String::escapeForRegExp(kernel);
 
 	String regex="[ \t]*(image|other)[ \t]*=[ \t]*\"?"+t+"\"?[ \t]*";
 	for(liloimages::iterator it=images.begin(); it!=images.end(); it++) {
